_antonyms = {
    "способность": "неспособность",
    "ненормальный": "в своем уме",
    "упразднять": "установить",
    "отсутствие": "присутствие",
    "нет на месте": "настоящее время",
    "будущее": "мимо",
    "абсолютный": "относительный",
    "воздерживаться": "акт",
    "абстрактные": "бетон",
    "изобилие": "дефицит",
    "обильный": "дефицитный",
    "принимать": "отклонять",
    "признавать": "отрицать",
    "приемлемо": "неприемлемо",
    "принятие": "отказ",
    "доступной": "недоступный",
    "точный": "неточный",
    "признанный": "непризнанный",
    "знакомство": "незнакомец",
    "акт": "воздерживаться",
    "действие": "в бою",
    "активный": "тихо",
    "сохранившийся": "потухший",
    "шумный": "тихо",
    "мероприятия": "бездеятельность",
    "фактический": "потенциал",
    "добавить": "вычитать",
    "прибавление": "вычитание",
    "адекватный": "неадекватный",
    "имя прилагательное": "основной",
    "допустимый": "недопустимый",
    "для взрослых": "ювенильный",
    "продвижение": "убывать",
    "впереди": "назад",
    "фронт": "задний",
    "травить": "назад",
    "преимущество": "недостаток",
    "утверждение": "неодобрение",
    "утвердительный": "отрицательный",
    "нейтральный": "отрицательный",
    "кормовой": "носовой",
    "возраст": "омолаживать",
    "престарелый": "молодой",
    "агитация": "спокойствие",
    "дать согласие": "не соглашаться",
    "приятный": "неприятный",
    "соглашение": "разногласие",
    "изменено": "без изменений",
    "чередовать": "напротив",
    "любитель": "профессиональный",
    "двусмысленный": "недвусмысленный",
    "дружный": "враждебный",
    "дружелюбный": "недружественный",
    "десантный": "земной",
    "анальный": "пероральный",
    "аналогичный": "непохожий",
    "анализ": "синтез",
    "аналитический": "синтетический",
    "предок": "потомок",
    "угловая": "закругленный",
    "оживлять": "неодушевленный",
    "ответ": "вопрос",
    "антагонистический": "синергистический",
    "предшествующее": "последующий",
    "передний": "задний",
    "антисептик": "септический",
    "появление": "исчезновение",
    "признательность": "амортизация",
    "одобрить": "не одобрять",
    "водный": "изверженный",
    "земной": "небесный",
    "рука": "разоружаться",
    "вооруженный": "безоружный",
    "прибыть": "оставлять",
    "восходить": "сходить",
    "восхождение": "спуск",
    "спящий": "бодрствующий",
    "соизволение": "разногласие",
    "асимметрия": "симметрия",
    "атеизм": "теизм",
    "прикреплять": "отрывать",
    "атака": "защищать",
    "преследовать в судебном порядке": "защищать",
    "внимание": "невнимательность",
    "привлечение": "отталкивание",
    "слышимый": "неслышный",
    "увеличение": "снижение",
    "тетка": "дядя",
    "уполномоченный": "неразрешенный",
    "автоматический": "руководство",
    "избежать": "противостоять",
    "бодрствующий": "спящий",
    "назад": "вперед",
    "убывать": "воск",
    "задний": "передний",
    "задний план": "передний план",
    "задний ход": "лицевой",
    "плохо": "хорошо",
    "зло": "хорошо",
    "негодность": "доброта",
    "сбалансированный": "несбалансированный",
    "медведь": "бык",
    "красивая": "уродливый",
    "красота": "уродство",
    "начать": "конец",
    "начало": "средний",
    "рано": "поздно",
    "вера": "неверие",
    "изгиб": "выпрямлять",
    "доброкачественный": "злокачественный",
    "большой": "маленький",
    "рождение": "смерть",
    "бисексуал": "гомосексуальный",
    "черный": "белый",
    "благословить": "проклятие",
    "благословенный": "проклят",
    "бескровный": "кровавый",
    "кровавый": "бескровный",
    "пятно": "фокус",
    "кипятить": "замерзать",
    "жирный": "робкий",
    "смелость": "робость",
    "заимствовать": "давать в долг",
    "заемщик": "кредитор",
    "дно": "вверх",
    "связанный": "несвязанный",
    "мальчик": "девушка",
    "бойкотировать": "покровительствовать",
    "ломать": "ремонт",
    "ломкий": "неуязвимый",
    "просиять": "темнеть",
    "светлеть": "темнеть",
    "сломанный": "непрерывный",
    "брат": "сестра",
    "бык": "медведь",
    "занятый": "незанятый",
    "работа": "вхолостую",
    "купить": "продавать",
    "спокойный": "штормовой",
    "спокойствие": "агитация",
    "способный": "неспособный",
    "вместимость": "недееспособность",
    "денежные средства": "кредит",
    "дебет": "кредит",
    "центр": "оставил",
    "церебральный": "эмоциональный",
    "определенность": "неопределенность",
    "изменение": "оставаться",
    "отходить": "оставаться",
    "переехать": "оставаться",
    "сменный": "неизменяемый",
    "заряд": "разряд",
    "завербоваться": "разряд",
    "дешево": "дорогая",
    "ура": "жаловаться",
    "веселая": "унылый",
    "ребенок": "родитель",
    "гражданский": "военные",
    "запрос": "утрачивать",
    "ясность": "помутнение",
    "протуберанец": "неясность",
    "прозрачность": "помутнение",
    "чистый": "нечистый",
    "духовенство": "миряне",
    "священник": "неспециалист",
    "закрыть": "открытый",
    "закрыто": "открытый",
    "закрыть": "открытый",
    "близость": "открытость",
    "береговой": "внутренний",
    "последовательный": "бессвязный",
    "холодно": "горячий",
    "обеспечение": "прямой",
    "комедия": "трагедия",
    "комфорт": "дискомфорт",
    "общий": "редкий",
    "совместимый": "несовместимый",
    "компетентность": "некомпетентность",
    "компетентный": "некомпетентный",
    "соревнование": "сотрудничество",
    "жаловаться": "ура",
    "полнота": "пустота",
    "сложный": "просто",
    "соединение": "просто",
    "уступчивый": "дерзкий",
    "усложнять": "упрощать",
    "вогнутый": "выпуклый",
    "тщеславие": "смирение",
    "гордость": "смирение",
    "концентрация": "распределение",
    "концентрический": "эксцентричный",
    "концепция": "неправильное представление",
    "обеспокоенный": "беззаботный",
    "бетон": "абстрактные",
    "подтвердил": "неподтвержденный",
    "противостоять": "избежать",
    "сослагательное наклонение": "разъединяющий",
    "соединять": "отключить",
    "сознание": "беспамятство",
    "консервативный": "либеральный",
    "консервировать": "отходы",
    "внимательный": "невнимательный",
    "консистенция": "несогласованность",
    "согласный": "гласная буква",
    "бросающийся в глаза": "незаметный",
    "конституционная": "неконституционный",
    "потреблять": "воздерживаться",
    "содержание": "недовольство",
    "постоянный": "бег",
    "продолжение": "прекращение",
    "продолжать": "прекращать",
    "непрерывность": "разрыв",
    "непрерывный": "сломанный",
    "контракт": "расширенный",
    "сокращение": "расширение",
    "удобный": "неудобный",
    "обычный": "необычный",
    "сходиться": "расходиться",
    "конвергенция": "дивергенция",
    "сходящийся": "расходящийся",
    "выпуклый": "вогнутый",
    "убежденный": "убедило",
    "круто": "высокая температура",
    "сотрудничество": "соревнование",
    "космополит": "провинциальный",
    "мужество": "трусость",
    "обложка": "раскрывать",
    "завуалированный": "неприкрытый",
    "трусость": "мужество",
    "кредит": "дебет",
    "кредитор": "заемщик",
    "критиковать": "хвалить",
    "плакать": "смех",
    "излечим": "неизлечимый",
    "проклятие": "благословить",
    "проклят": "благословенный",
    "изогнутый": "прямо",
    "порез": "неразрезанный",
    "опасность": "безопасность",
    "опасно": "безопасно",
    "темно": "легкий",
    "темнеть": "светлеть",
    "темнота": "расторопность",
    "инертность": "расторопность",
    "дочь": "сын",
    "день": "ночь",
    "глухой": "слух",
    "смерть": "рождение",
    "должник": "кредитор",
    "порядочность": "непристойность",
    "порядочный": "неприличный",
    "лиственный": "вечнозеленый",
    "решение": "нерешительность",
    "решающий": "нерешительный",
    "снижение": "увеличение",
    "снизилась": "вырос",
    "декремент": "приращение",
    "поражение": "победа",
    "защищать": "преследовать в судебном порядке",
    "ответчик": "истец",
    "защита": "судебное преследование",
    "оборонительный": "наступление",
    "дерзкий": "уступчивый",
    "дефицит": "изобилие",
    "определенный": "не определено",
    "дефляция": "инфляция",
    "задержка": "порыв",
    "задерживаться": "порыв",
    "спрос": "поставка",
    "отрицать": "признавать",
    "отклонять": "принимать",
    "зависимый": "независимый",
    "депозит": "изымать",
    "амортизация": "признательность",
    "унылый": "веселая",
    "сходить": "восходить",
    "потомок": "предок",
    "спуск": "восхождение",
    "описательный": "предписывающий",
    "желательный": "нежелательный",
    "отчаяние": "надежда",
    "отчаянный": "надежда",
    "безрассудство": "мудрость",
    "разрушенный": "сохраняется",
    "отрывать": "прикреплять",
    "деволюция": "эволюция",
    "отличаться": "равный",
    "неравный": "равный",
    "разница": "одинаковость",
    "сложно": "легко",
    "беспокойный": "легко",
    "трудность": "легкость",
    "прилежный": "нерадивый",
    "разведение": "концентрация",
    "распределение": "концентрация",
    "убывание": "увеличение",
    "грязный": "чистый",
    "нечистый": "чистый",
    "запрещать": "включить",
    "недостаток": "преимущество",
    "не соглашаться": "дать согласие",
    "противный": "приятный",
    "разногласие": "соизволение",
    "исчезновение": "появление",
    "неодобрение": "утверждение",
    "не одобрять": "одобрить",
    "разоружаться": "рука",
    "разряд": "завербоваться",
    "отказываться": "запрос",
    "утрачивать": "запрос",
    "дискомфорт": "комфорт",
    "отключить": "соединять",
    "недовольство": "содержание",
    "прекращение": "продолжение",
    "прекращать": "продолжать",
    "разрыв": "непрерывность",
    "прерывистый": "непрерывный",
    "отговаривать": "поощрять",
    "уныние": "поощрение",
    "выключать": "заниматься",
    "нечестный": "честный",
    "нечестность": "честность",
    "бесчестие": "честь",
    "дезинфицировать": "заражать",
    "распадаться": "интегрировать",
    "разъединяющий": "сослагательное наклонение",
    "нелюбовь": "симпатия",
    "вытеснять": "домик",
    "непослушание": "послушание",
    "непослушный": "послушный",
    "не слушаться": "подчиниться",
    "расстройство": "заказ",
    "беспорядочный": "упорядоченный",
    "дезорганизованный": "организованная",
    "неорганизованный": "организованная",
    "недовольный": "довольный",
    "опровергать": "доказывать",
    "дисквалифицировать": "квалифицировать",
    "постыдный": "уважаемый",
    "дурная слава": "репутация",
    "неуважение": "уважение",
    "непочтительный": "благоговейный",
    "неудовлетворенность": "удовлетворение",
    "вред": "оказание услуг",
    "непохожий": "аналогичный",
    "диссонанс": "гармония",
    "разубеждать": "уговаривать",
    "дистальный": "проксимальный",
    "отдаленный": "закрыть",
    "открытый": "закрыть",
    "различимый": "незаметный",
    "недоверие": "доверять",
    "суточный": "ночной",
    "расходиться": "сходиться",
    "дивергенция": "конвергенция",
    "расходящийся": "сходящийся",
    "делить": "объединять",
    "отдельно": "умножать",
    "разделенный": "единый",
    "делимый": "неделимый",
    "внутренний": "внешний",
    "родной": "иностранные",
    "доминирующий": "подчиненный",
    "бездействующий": "активный",
    "потухший": "сохранившийся",
    "неактивный": "активный",
    "пассивный": "активный",
    "тихо": "шумный",
    "двойной": "один",
    "множественный": "один",
    "голубь": "ястреб",
    "драматичный": "лирический",
    "сухой": "влажный",
    "кислый": "подслащивать",
    "в связи": "несвоевременный",
    "скучный": "точить",
    "расплющить": "точить",
    "умирающий": "рождающийся",
    "легкость": "трудность",
    "легко": "беспокойный",
    "отлив": "волна",
    "эксцентричный": "концентрический",
    "образованный": "необразованный",
    "эффективный": "неэффективный",
    "эффективность": "неэффективность",
    "эффективное": "неэффективный",
    "выход": "вход",
    "эластичный": "неэластичный",
    "право": "неподходящий",
    "эмоциональный": "церебральный",
    "эмпирический": "теоретический",
    "пустота": "полнота",
    "пустой": "полный",
    "тонкий": "сгущаться",
    "включить": "запрещать",
    "поощрять": "отговаривать",
    "поощрение": "уныние",
    "конец": "начало",
    "окончание": "начало",
    "средний": "рано",
    "эндемический": "космополит",
    "провинциальный": "космополит",
    "энергичный": "летаргический",
    "обеспечивать соблюдение": "освобожденный",
    "заниматься": "выключать",
    "наслаждаться": "страдать",
    "войти": "выход",
    "равный": "неравный",
    "равенство": "неравенство",
    "экваториальный": "полярный",
    "равноправный": "несправедливый",
    "сомнительный": "недвусмысленный",
    "стирать": "запись",
    "установить": "упразднять",
    "богатый событиями": "беспрецедентна",
    "вечнозеленый": "лиственный",
    "эволюция": "деволюция",
    "исключение": "включение",
    "освобожденный": "обеспечивать соблюдение",
    "выдыхать": "вдыхать",
    "существующий": "несуществующий",
    "выход": "войти",
    "расширять": "узкий",
    "расширенный": "контракт",
    "расширение": "сгибание",
    "ожидаемый": "неожиданный",
    "дорогая": "дешево",
    "опытный": "неопытный",
    "экспорт": "импортировать",
    "экспресс": "местный",
    "генеральная": "конкретный",
    "национальный": "международный",
    "экстерьер": "интерьер",
    "внешний": "свойственный",
    "внешне": "внутренне",
    "тушить": "воспламеняться",
    "заочный": "очный",
    "необычайный": "обычный",
    "провал": "прохождение",
    "бег": "постоянный",
    "отказ": "принятие",
    "справедливая": "недобросовестный",
    "верный": "вероломный",
    "падать": "подъем",
    "задавать": "подъем",
    "ошибочный": "непогрешимый",
    "падение": "поднимающийся",
    "ложность": "правда",
    "известность": "гнусность",
    "знакомые": "незнакомый",
    "маскарадный": "гладкий",
    "жир": "тонкий",
    "полный": "пустой",
    "толстый": "тонкий",
    "сгущаться": "тонкий",
    "отец": "мама",
    "фауна": "флора",
    "благоприятный": "неблагоприятный",
    "федеральный": "унитарный",
    "женский пол": "мужской",
    "женский": "бесполый",
    "женственность": "мужественность",
    "плодородный": "стерильный",
    "верность": "неверность",
    "фигура": "земля",
    "заполнить": "пустой",
    "найти": "потерять",
    "конец": "начало",
    "стоп": "начало",
    "конечный": "бесконечный",
    "огонь": "наем",
    "сгибание": "расширение",
    "поплавок": "раковина",
    "источник": "раковина",
    "флора": "фауна",
    "фокус": "пятно",
    "недоброжелатель": "друг",
    "складка": "раскрываться",
    "следовать": "предшествовать",
    "добиться успеха": "предшествовать",
    "последователь": "лидер",
    "глупый": "мудрый",
    "фут": "глава",
    "хвост": "глава",
    "запретить": "разрешать",
    "носовой": "кормовой",
    "передний план": "задний план",
    "иностранные": "родной",
    "забывать": "запомнить",
    "всепрощающий": "неумолимый",
    "формализм": "имитация",
    "удачливый": "несчастный",
    "вперед": "задний ход",
    "лицевой": "задний ход",
    "фол": "справедливая",
    "недобросовестный": "щепетильный",
    "найденный": "потерял",
    "братский": "идентичный",
    "замерзать": "кипятить",
    "частый": "нечастый",
    "часто": "не часто",
    "друг": "недоброжелатель",
    "глава": "хвост",
    "функциональная": "органический",
    "неорганический": "органический",
    "усиление": "потеря",
    "газообразный": "твердый",
    "полый": "твердый",
    "собирать": "распространение",
    "всеобщность": "особенность",
    "великодушный": "скупой",
    "девушка": "мальчик",
    "хорошо": "зло",
    "доброта": "негодность",
    "постепенный": "внезапно",
    "благодарный": "неблагодарный",
    "большая": "меньший",
    "зеленый": "созревший",
    "валовой": "сеть",
    "земля": "фигура",
    "вина": "невинность",
    "виновный": "невинный",
    "счастливо": "грустно",
    "счастье": "несчастье",
    "счастливый": "несчастный",
    "твердость": "мягкость",
    "громкость": "мягкость",
    "острота": "мягкость",
    "гармония": "диссонанс",
    "ненавидеть": "люблю",
    "ненавистный": "привлекательный",
    "ястреб": "голубь",
    "здоровый": "нездоровый",
    "слух": "глухой",
    "высокая температура": "круто",
    "небесный": "земной",
    "разнородность": "гомогенность",
    "скрывать": "показать",
    "наем": "огонь",
    "удар": "мисс",
    "святой": "нечестивый",
    "гомогенность": "разнородность",
    "гомологичны": "аналогичный",
    "гомосексуальный": "бисексуал",
    "честный": "нечестный",
    "честность": "нечестность",
    "честь": "бесчестие",
    "надежда": "безрассудство",
    "многообещающий": "безнадежный",
    "безнадежный": "многообещающий",
    "горизонтальный": "вертикальный",
    "враждебный": "дружелюбный",
    "недружественный": "дружелюбный",
    "горячий": "холодно",
    "смиренный": "гордый",
    "смирение": "гордость",
    "голодный": "жаждущий",
    "идентичный": "братский",
    "вхолостую": "работа",
    "изверженный": "водный",
    "воспламеняться": "тушить",
    "игнорировать": "уведомление",
    "нелегальный": "правовой",
    "незаконность": "легальность",
    "неразборчивый": "разборчивый",
    "нелогичный": "логический",
    "имитация": "формализм",
    "несущественный": "материал",
    "незрелость": "зрелость",
    "неизмеримый": "измеримый",
    "аморальный": "моральный",
    "безнравственность": "мораль",
    "бессмертный": "смертный",
    "бессмертие": "смертность",
    "неизменный": "изменчивый",
    "беспристрастность": "пристрастность",
    "непроходимый": "проходимый",
    "нетерпение": "терпение",
    "нетерпеливый": "пациент",
    "незаметный": "бросающийся в глаза",
    "дефектность": "совершенство",
    "непроницаемый": "проницаемый",
    "недопустимый": "допустимый",
    "безличный": "личный",
    "невежливый": "вежливый",
    "импортировать": "экспорт",
    "важный": "неважный",
    "невозможность": "возможность",
    "бессильный": "мощный",
    "невероятный": "вероятный",
    "улучшен": "необработанный",
    "улучшение": "снижение",
    "неосторожный": "осторожный",
    "примесь": "чистота",
    "неспособность": "способность",
    "недоступный": "доступной",
    "неточный": "точный",
    "в бою": "действие",
    "бездеятельность": "мероприятия",
    "неадекватный": "адекватный",
    "неодушевленный": "оживлять",
    "невнимательность": "внимание",
    "неслышный": "слышимый",
    "неспособный": "способный",
    "недееспособность": "вместимость",
    "наклонный": "горизонтальный",
    "вертикальный": "горизонтальный",
    "включение": "исключение",
    "бессвязный": "последовательный",
    "несовместимый": "совместимый",
    "некомпетентность": "компетентность",
    "некомпетентный": "компетентный",
    "неполнота": "полнота",
    "невнимательный": "внимательный",
    "несогласованность": "консистенция",
    "неудобный": "удобный",
    "вырос": "снизилась",
    "приращение": "декремент",
    "неизлечимый": "излечим",
    "непристойность": "порядочность",
    "неприличный": "порядочный",
    "нерешительность": "решение",
    "нерешительный": "решающий",
    "независимый": "зависимый",
    "неразличимый": "различимый",
    "неделимый": "делимый",
    "в помещении": "на открытом воздухе",
    "неэффективный": "эффективное",
    "неэффективность": "эффективность",
    "неэластичный": "эластичный",
    "неподходящий": "право",
    "неравенство": "равенство",
    "несправедливый": "равноправный",
    "неопытный": "опытный",
    "непогрешимый": "ошибочный",
    "гнусность": "известность",
    "заражать": "дезинфицировать",
    "низший": "превосходящий",
    "низкое качество": "превосходство",
    "неверность": "верность",
    "бесконечный": "конечный",
    "инфляция": "дефляция",
    "проинформировал": "несведущий",
    "нечастый": "частый",
    "не часто": "часто",
    "вход": "выход",
    "обитаемый": "необитаемый",
    "вдыхать": "выдыхать",
    "несправедливость": "справедливость",
    "невинность": "вина",
    "невинный": "виновный",
    "безвредный": "вредный",
    "недействующий": "оперативный",
    "невменяемость": "вменяемость",
    "ненадежность": "безопасность",
    "незначительность": "значение",
    "незначительный": "главный",
    "нерастворимый": "растворимый",
    "неплатежеспособность": "кредитоспособность",
    "несостоятельный": "растворитель",
    "нестабильность": "стабильность",
    "инструментальный": "вокальный",
    "недостаточность": "достаточность",
    "недостаточное": "достаточно",
    "недостаточно": "достаточно",
    "интегрировать": "распадаться",
    "интеграция": "сегрегация",
    "интеллект": "тупость",
    "вразумительный": "невразумительный",
    "предназначена": "непреднамеренный",
    "намеренно": "нечаянно",
    "заинтересованный": "незаинтересованный",
    "интересно": "неинтересный",
    "интерьер": "экстерьер",
    "промежуточный": "терминал",
    "внутренне": "внешне",
    "международный": "национальный",
    "местный": "генеральная",
    "непереносимость": "толерантность",
    "нетерпимый": "терпимый",
    "неподатливый": "послушный",
    "очный": "заочный",
    "свойственный": "внешний",
    "невидимость": "видимость",
    "невидимый": "видимый",
    "непроизвольный": "добровольный",
    "иррациональный": "рациональный",
    "нерегулярный": "регулярный",
    "неправильность": "регулярность",
    "не имеет значения": "соответствующий",
    "безответственный": "ответственность",
    "вопрос": "ответ",
    "совместный": "отдельный",
    "радость": "печаль",
    "радостный": "скорбный",
    "младший": "старшая",
    "справедливость": "несправедливость",
    "ювенильный": "для взрослых",
    "деревенщина": "деревенщина",
    "своего рода": "недобрый",
    "король": "королева",
    "миряне": "духовенство",
    "поздно": "рано",
    "смех": "плакать",
    "законный": "незаконное",
    "рыхлый": "напряженный",
    "расслабленный": "напряженный",
    "неспециалист": "священник",
    "вести": "дефицит",
    "лидер": "последователь",
    "оставлять": "прибыть",
    "оставил": "центр",
    "правовой": "нелегальный",
    "легальность": "незаконность",
    "легализовать": "вне закона",
    "разборчивый": "неразборчивый",
    "давать в долг": "заимствовать",
    "удлинять": "укорачивать",
    "меньший": "большая",
    "летаргический": "энергичный",
    "уровень": "повышение",
    "ниже": "повышение",
    "либеральный": "консервативный",
    "ложь": "стоять",
    "уступать": "стоять",
    "легкий": "темно",
    "расторопность": "инертность",
    "симпатия": "нелюбовь",
    "ограниченное": "неограниченный",
    "прямой": "обеспечение",
    "жидкость": "газообразный",
    "твердый": "полый",
    "конкретный": "генеральная",
    "место нахождения": "студия",
    "замок": "отпереть",
    "домик": "вытеснять",
    "логический": "нелогичный",
    "длинный": "короткая",
    "высокий": "короткая",
    "рыхлить": "деревенеть",
    "потерять": "найти",
    "потеря": "усиление",
    "потерял": "найденный",
    "привлекательный": "ненавистный",
    "люблю": "ненавидеть",
    "везучий": "несчастливый",
    "лирический": "драматичный",
    "главный": "незначительный",
    "большинство": "меньшинство",
    "делать": "ломать",
    "ремонт": "ломать",
    "мужской": "женский",
    "злокачественный": "доброкачественный",
    "руководство": "автоматический",
    "отмеченный": "неотмеченный",
    "в браке": "незамужняя",
    "бесполый": "женский",
    "мужественность": "женственность",
    "маскировать": "разоблачать",
    "материал": "несущественный",
    "материнский": "отеческий",
    "зрелость": "незрелость",
    "максимальная": "минимальный",
    "измеримый": "неизмеримый",
    "умственный": "физическое",
    "милостивый": "беспощадный",
    "беспощадный": "милостивый",
    "военные": "гражданский",
    "разум": "забывать",
    "запомнить": "забывать",
    "минимальный": "максимальная",
    "меньшинство": "большинство",
    "неправильное представление": "концепция",
    "мисс": "удар",
    "молярный": "молекулярная",
    "молекулярная": "молярный",
    "моральный": "аморальный",
    "мораль": "безнравственность",
    "смертный": "бессмертный",
    "смертность": "бессмертие",
    "мама": "отец",
    "умножать": "отдельно",
    "объединять": "делить",
    "изменчивый": "неизменный",
    "надир": "зенит",
    "узкий": "расширять",
    "рождающийся": "умирающий",
    "отрицательный": "нейтральный",
    "нерадивый": "прилежный",
    "племянник": "племянница",
    "сеть": "валовой",
    "племянница": "племянник",
    "ночь": "день",
    "ночной": "суточный",
    "номинальный": "реальный",
    "нереально": "реалистический",
    "несуществующий": "существующий",
    "нормальный": "ненормальный",
    "уведомление": "игнорировать",
    "вредный": "безвредный",
    "численный": "словесный",
    "послушание": "непослушание",
    "послушный": "неподатливый",
    "подчиниться": "не слушаться",
    "задача": "субъективный",
    "обязательное": "необязательный",
    "косой": "перпендикуляр",
    "неясность": "протуберанец",
    "помутнение": "прозрачность",
    "преступление": "защита",
    "судебное преследование": "защита",
    "наступление": "оборонительный",
    "официальный": "неофициальный",
    "открытость": "близость",
    "оперативный": "недействующий",
    "против": "единственный",
    "напротив": "чередовать",
    "оптимизм": "пессимизм",
    "оптимист": "пессимист",
    "необязательный": "обязательное",
    "пероральный": "анальный",
    "заказ": "расстройство",
    "упорядоченный": "беспорядочный",
    "органический": "неорганический",
    "организованная": "неорганизованный",
    "ортодоксальный": "неортодоксальный",
    "на открытом воздухе": "в помещении",
    "вне закона": "легализовать",
    "переоценивать": "недооценивать",
    "накладные расходы": "поверхность",
    "неприкрытый": "завуалированный",
    "пак": "распаковывать",
    "болезненный": "безболезненный",
    "безболезненный": "болезненный",
    "параллельно": "косой",
    "перпендикуляр": "косой",
    "родитель": "ребенок",
    "пристрастность": "беспристрастность",
    "особенность": "всеобщность",
    "частично": "полностью",
    "проходимый": "непроходимый",
    "прохождение": "бег",
    "мимо": "будущее",
    "настоящее время": "нет на месте",
    "отеческий": "материнский",
    "терпение": "нетерпение",
    "пациент": "нетерпеливый",
    "покровительствовать": "бойкотировать",
    "мир": "война",
    "штраф": "награда",
    "совершенство": "дефектность",
    "проницаемый": "непроницаемый",
    "разрешающий": "превентивный",
    "разрешать": "запретить",
    "личный": "безличный",
    "уговаривать": "разубеждать",
    "пессимизм": "оптимизм",
    "пессимист": "оптимист",
    "физическое": "умственный",
    "гладкий": "маскарадный",
    "истец": "ответчик",
    "довольный": "недовольный",
    "множественное число": "единственное число",
    "полярный": "экваториальный",
    "вежливый": "невежливый",
    "популярный": "непопулярный",
    "пористость": "основательность",
    "возможность": "невозможность",
    "сильнодействующий": "бессильный",
    "потенциал": "фактический",
    "бедность": "богатство",
    "мощный": "бессильный",
    "хвалить": "критиковать",
    "предшествовать": "добиться успеха",
    "предшествующий": "последующий",
    "префикс": "суффикс",
    "подготовка": "разрешающая способность",
    "подготовленный": "неподготовленный",
    "предписывающий": "описательный",
    "присутствие": "отсутствие",
    "сохраняется": "разрушенный",
    "превентивный": "разрешающий",
    "первичный": "вторичный",
    "частный": "общественности",
    "в частном порядке": "публично",
    "вероятный": "невероятный",
    "продуктивный": "непродуктивный",
    "непосвященный": "священный",
    "профессиональный": "любитель",
    "прогресс": "регрессировать",
    "прогрессирующий": "регрессивный",
    "перспективный": "ретроспективный",
    "защищенный": "незащищенный",
    "гордый": "смиренный",
    "доказывать": "опровергать",
    "проксимальный": "дистальный",
    "ближайший": "окончательный",
    "предусмотрительный": "неосторожный",
    "общественности": "частный",
    "публично": "в частном порядке",
    "опубликованный": "неопубликованный",
    "вытащить": "от себя",
    "пунктуальность": "медлительность",
    "чистка": "реабилитировать",
    "чистота": "примесь",
    "от себя": "вытащить",
    "квалифицировать": "дисквалифицировать",
    "королева": "король",
    "под вопросом": "бесспорный",
    "быстро": "медленно",
    "повышение": "ниже",
    "рациональный": "иррациональный",
    "реальный": "нереально",
    "реалистический": "нереально",
    "успокаивать": "беспокоиться",
    "отзыв": "вопрос",
    "запись": "стирать",
    "отказаться": "принимать",
    "регрессировать": "прогресс",
    "регрессивный": "прогрессирующий",
    "регулярный": "нерегулярный",
    "регулярность": "неправильность",
    "регулируется": "нерегулируемый",
    "реабилитировать": "чистка",
    "омолаживать": "возраст",
    "связанный": "несвязанный",
    "относительный": "абсолютный",
    "соответствующий": "не имеет значения",
    "надежный": "ненадежный",
    "религиозная": "светский",
    "отталкивание": "привлечение",
    "уважаемый": "постыдный",
    "репутация": "дурная слава",
    "оказывать сопротивление": "сдача",
    "разрешающая способность": "подготовка",
    "уважение": "неуважение",
    "почтительный": "непочтительный",
    "ответственность": "безответственный",
    "сдержанный": "несдержанный",
    "ограниченный": "неограниченный",
    "ретроспективный": "перспективный",
    "благоговейный": "непочтительный",
    "реверс": "утверждение",
    "награда": "штраф",
    "поездка": "ходить",
    "созревший": "зеленый",
    "подъем": "задавать",
    "поднимающийся": "падение",
    "ротор": "статор",
    "шероховатость": "ровность",
    "круглый": "квадрат",
    "закругленный": "угловая",
    "сельская местность": "городской",
    "порыв": "задерживаться",
    "священный": "непосвященный",
    "грустно": "счастливо",
    "печаль": "радость",
    "несчастье": "счастье",
    "безопасно": "опасно",
    "безопасность": "ненадежность",
    "одинаковость": "разница",
    "в своем уме": "ненормальный",
    "вменяемость": "невменяемость",
    "удовлетворение": "неудовлетворенность",
    "чабер": "непривлекательный",
    "дефицитный": "обильный",
    "научный": "ненаучный",
    "щепетильный": "недобросовестный",
    "вторичный": "первичный",
    "светский": "религиозная",
    "сегрегация": "интеграция",
    "эгоистичный": "бескорыстный",
    "продавать": "купить",
    "старшая": "младший",
    "отдельный": "совместный",
    "разделение": "союз",
    "септический": "антисептик",
    "оказание услуг": "вред",
    "решен": "нерешенный",
    "точить": "расплющить",
    "короткая": "высокий",
    "укорачивать": "удлинять",
    "окрик": "шептать",
    "показать": "скрывать",
    "сокращаться": "протяжение",
    "боковая сторона": "дно",
    "вверх": "дно",
    "значение": "незначительность",
    "значительное": "незначительный",
    "просто": "соединение",
    "упрощать": "усложнять",
    "один": "множественный",
    "единственное число": "множественное число",
    "раковина": "источник",
    "сестра": "брат",
    "спать": "будить",
    "медленно": "быстро",
    "маленький": "большой",
    "ровность": "шероховатость",
    "мягкость": "острота",
    "основательность": "пористость",
    "растворимый": "нерастворимый",
    "кредитоспособность": "неплатежеспособность",
    "растворитель": "несостоятельный",
    "сын": "дочь",
    "скорбный": "радостный",
    "разговорный": "написано",
    "неписаный": "написано",
    "спорадический": "постоянный",
    "распространение": "собирать",
    "квадрат": "круглый",
    "стабильность": "нестабильность",
    "стабильный": "неустойчивый",
    "стоять": "уступать",
    "начало": "стоп",
    "статор": "ротор",
    "оставаться": "переехать",
    "неуклонный": "неустойчивый",
    "крутой": "постепенный",
    "внезапно": "постепенный",
    "стерильный": "плодородный",
    "деревенеть": "рыхлить",
    "скупой": "великодушный",
    "штормовой": "спокойный",
    "прямо": "изогнутый",
    "выпрямлять": "изгиб",
    "незнакомец": "знакомство",
    "прочность": "слабое место",
    "протяжение": "сокращаться",
    "сильно": "слабо",
    "студия": "место нахождения",
    "тупость": "интеллект",
    "субъективный": "задача",
    "подчиненный": "доминирующий",
    "последующий": "предшествующий",
    "основной": "имя прилагательное",
    "вычитать": "добавить",
    "вычитание": "прибавление",
    "успех": "отказ",
    "успешный": "неудачный",
    "поддаваться": "уцелеть",
    "страдать": "наслаждаться",
    "достаточность": "недостаточность",
    "достаточно": "недостаточно",
    "суффикс": "префикс",
    "восход": "закат солнца",
    "закат солнца": "восход",
    "превосходящий": "низший",
    "превосходство": "низкое качество",
    "поставка": "спрос",
    "поддержанный": "не поддерживается",
    "поверхность": "накладные расходы",
    "сдача": "оказывать сопротивление",
    "уцелеть": "поддаваться",
    "милая": "кислый",
    "влажный": "сухой",
    "подслащивать": "кислый",
    "симметрия": "асимметрия",
    "симпатичный": "несимпатичный",
    "синергистический": "антагонистический",
    "синтез": "анализ",
    "синтетический": "аналитический",
    "медлительность": "пунктуальность",
    "со вкусом": "безвкусный",
    "вкусно": "безвкусный",
    "безвкусный": "вкусно",
    "нежная": "жесткий",
    "напряженный": "расслабленный",
    "терминал": "промежуточный",
    "теизм": "атеизм",
    "теоретический": "эмпирический",
    "жаждущий": "голодный",
    "вдумчивый": "беспечный",
    "беспечный": "вдумчивый",
    "экономный": "расточительный",
    "волна": "отлив",
    "галстук": "развязывать",
    "робкий": "жирный",
    "робость": "смелость",
    "толерантность": "непереносимость",
    "терпимый": "нетерпимый",
    "зубчатый": "беззубый",
    "беззубый": "зубчатый",
    "прикоснулся": "нетронутый",
    "жесткий": "нежная",
    "трагедия": "комедия",
    "обученный": "неподготовленный",
    "доверять": "недоверие",
    "правда": "ложность",
    "уродство": "красота",
    "уродливый": "красивая",
    "окончательный": "ближайший",
    "неприемлемо": "приемлемо",
    "непризнанный": "признанный",
    "неизмененный": "изменено",
    "недвусмысленный": "сомнительный",
    "безоружный": "вооруженный",
    "неразрешенный": "уполномоченный",
    "несбалансированный": "сбалансированный",
    "неверие": "вера",
    "несвязанный": "связанный",
    "неуязвимый": "ломкий",
    "неопределенность": "определенность",
    "неизменяемый": "сменный",
    "без изменений": "изменено",
    "дядя": "тетка",
    "редкий": "общий",
    "беззаботный": "обеспокоенный",
    "неподтвержденный": "подтвердил",
    "беспамятство": "сознание",
    "неконституционный": "конституционная",
    "нетрадиционный": "обычный",
    "убедило": "убежденный",
    "раскрывать": "обложка",
    "неразрезанный": "порез",
    "не определено": "определенный",
    "недооценивать": "переоценивать",
    "нежелательный": "желательный",
    "несвоевременный": "в связи",
    "необразованный": "образованный",
    "беспрецедентна": "богатый событиями",
    "неожиданный": "ожидаемый",
    "вероломный": "верный",
    "незнакомый": "знакомые",
    "неблагоприятный": "благоприятный",
    "раскрываться": "складка",
    "неумолимый": "всепрощающий",
    "несчастный": "счастливый",
    "неблагодарный": "благодарный",
    "нездоровый": "здоровый",
    "нечестивый": "святой",
    "неважный": "важный",
    "необработанный": "улучшен",
    "несведущий": "проинформировал",
    "необитаемый": "обитаемый",
    "невразумительный": "вразумительный",
    "непреднамеренный": "предназначена",
    "нечаянно": "намеренно",
    "незаинтересованный": "заинтересованный",
    "неинтересный": "интересно",
    "союз": "разделение",
    "унитарный": "федеральный",
    "единый": "разделенный",
    "недобрый": "своего рода",
    "незаконное": "законный",
    "неограниченный": "ограниченный",
    "отпереть": "замок",
    "несчастливый": "везучий",
    "неотмеченный": "отмеченный",
    "незамужняя": "в браке",
    "разоблачать": "маскировать",
    "незанятый": "занятый",
    "неофициальный": "официальный",
    "единственный": "против",
    "неортодоксальный": "ортодоксальный",
    "распаковывать": "пак",
    "неприятный": "приятный",
    "непопулярный": "популярный",
    "неподготовленный": "обученный",
    "непродуктивный": "продуктивный",
    "незащищенный": "защищенный",
    "неопубликованный": "опубликованный",
    "бесспорный": "под вопросом",
    "нерегулируемый": "регулируется",
    "ненадежный": "надежный",
    "несдержанный": "сдержанный",
    "непривлекательный": "чабер",
    "ненаучный": "научный",
    "бескорыстный": "эгоистичный",
    "нерешенный": "решен",
    "неустойчивый": "неуклонный",
    "неудачный": "успешный",
    "не поддерживается": "поддержанный",
    "несимпатичный": "симпатичный",
    "развязывать": "галстук",
    "нетронутый": "прикоснулся",
    "необычный": "обычный",
    "открывать": "вуаль",
    "неохотно": "охотно",
    "нежелание": "готовность",
    "размотать": "ветер",
    "недостойный": "достойный",
    "городской": "сельская местность",
    "ценный": "бесполезный",
    "вуаль": "открывать",
    "словесный": "численный",
    "победа": "поражение",
    "добродетельный": "злой",
    "видимость": "невидимость",
    "видимый": "невидимый",
    "вокальный": "инструментальный",
    "добровольный": "непроизвольный",
    "гласная буква": "согласный",
    "будить": "спать",
    "ходить": "поездка",
    "война": "мир",
    "осторожный": "неосторожный",
    "отходы": "консервировать",
    "расточительный": "экономный",
    "воск": "убывать",
    "слабо": "сильно",
    "слабое место": "прочность",
    "богатство": "бедность",
    "невесомый": "весомый",
    "весомый": "невесомый",
    "шептать": "окрик",
    "белый": "черный",
    "полностью": "частично",
    "злой": "добродетельный",
    "широкий": "узкий",
    "охотно": "неохотно",
    "готовность": "нежелание",
    "ветер": "размотать",
    "мудрость": "безрассудство",
    "мудрый": "глупый",
    "изымать": "депозит",
    "беспокоиться": "успокаивать",
    "бесполезный": "ценный",
    "достойный": "недостойный",
    "написано": "неписаный",
    "молодой": "престарелый",
    "зенит": "надир",
}



_antonyms = {
    "evnen": "manglende evne",
    "unormal": "normal",
    "avskaffe": "etablere",
    "fravær": "tilstedeværelse",
    "fraværende": "nåværende",
    "framtid": "forbi",
    "absolutte": "slektning",
    "avstå": "handling",
    "abstrakt": "betong",
    "overflod": "knapphet",
    "rikelig": "knapp",
    "aksepterer": "avvise",
    "innrømme": "benekte",
    "akseptabel": "uakseptabelt",
    "godkjennelse": "avvisning",
    "tilgjengelig": "utilgjengelig",
    "korrekt": "unøyaktig",
    "anerkjente": "besvares",
    "bekjent": "fremmed",
    "handling": "passivitet",
    "aktiv": "stille",
    "bevart": "ødelagt",
    "støyende": "stille",
    "aktivitet": "inaktivitet",
    "faktiske": "potensial",
    "legg til": "trekke fra",
    "addisjon": "subtraksjon",
    "tilstrekkelig": "utilstrekkelig",
    "adjektiv": "materielle",
    "tillatelig": "utillatelig",
    "voksen": "ungdoms-",
    "avansere": "svekkes",
    "fremover": "tilbake",
    "front": "iden",
    "veer": "tilbake",
    "fordel": "ulempe",
    "bekreftelse": "reversering",
    "bekreftende": "negativ",
    "nøytral": "negativ",
    "akter": "forgrunnen",
    "alder": "forynge",
    "aldrende": "ung",
    "agitasjon": "ro",
    "bli enige": "være uenig",
    "behagelig": "ubehagelig",
    "avtale": "uenighet",
    "endret": "uendret",
    "alternere": "motsatte",
    "amatør": "profesjonell",
    "tvetydig": "utvetydig",
    "minnelig": "fiendtlig",
    "vennlig": "uvennlig",
    "amfibiske": "bakkenett",
    "anal": "muntlig",
    "analogt": "homolog",
    "analyse": "syntese",
    "analytisk": "syntetisk",
    "stamfar": "kommer",
    "vinkel": "avrundet",
    "animere": "livløse",
    "svar": "spørsmål",
    "antagonistisk": "synergistisk",
    "forutgående": "senere",
    "anterior": "posterior",
    "antiseptisk middel": "septisk",
    "utseende": "forsvinning",
    "verdsettelse": "avskrivninger",
    "godkjenning": "misbilligelse",
    "vedta": "mislike",
    "akvatisk": "amfibiske",
    "bakkenett": "amfibiske",
    "vandig": "vulkanske",
    "væpne": "avvæpne",
    "bevæpnet": "ubevæpnet",
    "ankomme": "permisjon",
    "stige": "sett",
    "stigning": "avstamning",
    "sover": "våken",
    "samtykke": "dissens",
    "asymmetri": "symmetri",
    "ateisme": "teisme",
    "feste": "løsne",
    "angrep": "forsvare",
    "tiltale": "forsvar",
    "oppmerksomhet": "uoppmerksomhet",
    "tiltrekning": "frastøting",
    "hørbar": "uhørlig",
    "forstørrelse": "reduksjon",
    "tante": "onkel",
    "autorisert": "uautorisert",
    "automatisk": "håndbok",
    "unngå": "konfrontere",
    "våken": "sover",
    "tilbake": "veer",
    "svekkes": "avansere",
    "iden": "hode",
    "bakgrunn": "forgrunnen",
    "bakover": "framover",
    "omvendt": "advers",
    "dårlig": "flink",
    "ond": "dydig",
    "ondskap": "godhet",
    "balanserte": "ubalansert",
    "bjørn": "okse",
    "vakker": "stygg",
    "skjønnhet": "stygghet",
    "begynne": "slutt",
    "begynnelse": "midten",
    "tidlig": "sent",
    "tro": "vantro",
    "bøye": "rette",
    "godartet": "ondartet",
    "stor": "liten",
    "fødsel": "død",
    "biseksuell": "homoseksuell",
    "svart": "hvit",
    "velsigne": "forbannelse",
    "velsignet": "forbannet",
    "ublodig": "blodig",
    "blodig": "ublodig",
    "uklarhet": "fremtredende",
    "kok opp": "fryse",
    "dristig": "sjenert",
    "dristighet": "fryktsomhet",
    "låne": "låne",
    "låner": "utlåner",
    "bunn": "topp",
    "bundet": "ubundet",
    "gutt": "pike",
    "boikott": "nedlatende",
    "gå i stykker": "reparere",
    "knuselig": "uknuselig",
    "lysne": "mørkere",
    "lette": "mørkere",
    "gått i stykker": "ubrutt",
    "bror": "søster",
    "okse": "bjørn",
    "opptatt": "tomgang",
    "arbeid": "tomgang",
    "kjøpe": "selge",
    "rolig": "storm-",
    "ro": "agitasjon",
    "i stand": "ikke i stand til",
    "kapasitet": "uførhet",
    "penger": "kreditt",
    "debet": "kreditt",
    "senter": "venstre",
    "cerebral": "emosjonelle",
    "sikkerhet": "usikkerhet",
    "endring": "oppholde seg",
    "reise": "oppholde seg",
    "bevege seg": "oppholde seg",
    "foranderlig": "uforanderlige",
    "lade": "utladning",
    "verve": "utladning",
    "billig": "dyrt",
    "oppmuntre": "fraråde",
    "munter": "deprimerende",
    "barn": "forelder",
    "sivil": "militær",
    "krav": "gi opp",
    "klarhet": "opasitet",
    "fremtredende": "uklarhet",
    "åpenhet": "nærhet",
    "ren": "urent",
    "geistlige": "lekfolket",
    "prest": "lekmann",
    "lukk": "åpen",
    "lukket": "åpen",
    "lukke": "åpen",
    "nærhet": "åpenhet",
    "kyst": "inn i landet",
    "sammenhengende": "usammenhengende",
    "kald": "varmt",
    "komedie": "tragedie",
    "komfort": "ubehag",
    "felles": "uvanlig",
    "kompatibel": "trassig",
    "kompetanse": "inkompetanse",
    "kompetent": "inkompetent",
    "konkurranse": "samarbeid",
    "klage": "oppmuntre",
    "fullstendighet": "ufullstendighet",
    "komplekse": "enkel",
    "forbindelse": "enkel",
    "komplisere": "forenkle",
    "konkav": "konveks",
    "innbilskhet": "ydmykhet",
    "stolthet": "ydmykhet",
    "konsentrasjon": "fordeling",
    "konsentriske": "eksentriske",
    "oppfatning": "misforståelse",
    "bekymret": "likegyldig",
    "betong": "abstrakt",
    "bekreftet": "ubekreftet",
    "konfrontere": "unngå",
    "konjunktiv": "disjunktiv",
    "koble": "koble fra",
    "tilkoblet": "usammenhengende",
    "bevissthet": "bevisstløshet",
    "konservative": "liberal",
    "spare": "avfall",
    "hensyns": "hensynsløs",
    "konsistens": "inkonsekvens",
    "konsonant": "vokal",
    "iøynefallende": "iøynefallende",
    "konstitusjonell": "grunnlovsstridig",
    "forbruke": "avstå",
    "innhold": "misnøye",
    "kontinuerlig": "sporadisk",
    "videreføring": "opphør",
    "fortsette": "avvikle",
    "kontinuitet": "diskontinuitet",
    "kontinuerlige": "usammenhengende",
    "kontrakt": "utvidet",
    "kontraksjon": "ekspansjon",
    "beleilig": "upraktisk",
    "konvensjonell": "ukonvensjonell",
    "konvergerer": "divergere",
    "konvergens": "divergens",
    "konvergent": "avvikende",
    "konveks": "konkav",
    "overbevist": "overbevist",
    "kul": "varme",
    "samarbeid": "konkurranse",
    "cosmopolitan": "provinsiell",
    "mot": "feighet",
    "dekke": "avdekke",
    "skjult": "overt",
    "feighet": "mot",
    "kreditt": "debet",
    "kreditor": "debitor",
    "kritisere": "ros",
    "gråte": "latter",
    "herdbart": "uhelbredelig",
    "forbannelse": "velsigne",
    "forbannet": "velsignet",
    "krummet": "rett",
    "kutte opp": "uncut",
    "fare": "sikkerhet",
    "farlig": "sikker",
    "mørk": "lys",
    "mørkere": "lette",
    "mørke": "letthet",
    "tyngde": "letthet",
    "datter": "sønn",
    "dag": "natt",
    "døv": "hørsel",
    "død": "fødsel",
    "debitor": "kreditor",
    "anstendighet": "uanstendighet",
    "skikkelig": "uanstendig",
    "lauv": "evergreen",
    "beslutning": "ubesluttsomhet",
    "avgjørende": "ubesluttsom",
    "avslå": "forbedring",
    "avta": "øke",
    "redusert": "økt",
    "minsk": "tilvekst",
    "nederlag": "seier",
    "forsvare": "tiltale",
    "anklagede": "saksøker",
    "forsvar": "tiltale",
    "defensiv": "støtende",
    "trassig": "kompatibel",
    "underskudd": "lede",
    "definert": "udefinert",
    "deflasjon": "inflasjon",
    "utsette": "skynde",
    "dvele": "skynde",
    "kreve": "forsyning",
    "benekte": "innrømme",
    "avvise": "aksepterer",
    "avhengig": "uavhengig",
    "innskudd": "ta ut",
    "avskrivninger": "verdsettelse",
    "deprimerende": "munter",
    "gå ned": "stige",
    "kommer": "stamfar",
    "avstamning": "stigning",
    "beskrivende": "normative",
    "ønskelig": "uønsket",
    "fortvilelse": "håp",
    "desperat": "håp",
    "desperasjon": "håp",
    "ødelagt": "bevart",
    "løsne": "stive",
    "devolution": "utvikling",
    "avvike": "lik",
    "ulik": "lik",
    "forskjell": "likhet",
    "vanskelig": "mør",
    "urolig": "lett",
    "vanskelighet": "letthet",
    "flittig": "forsømmelig",
    "fortynning": "konsentrasjon",
    "fordeling": "konsentrasjon",
    "reduksjon": "forstørrelse",
    "skitne": "ren",
    "urent": "ren",
    "deaktivere": "aktiver",
    "ulempe": "fordel",
    "være uenig": "bli enige",
    "ubehagelig": "hyggelig",
    "uenighet": "avtale",
    "forsvinning": "utseende",
    "misbilligelse": "godkjenning",
    "mislike": "vedta",
    "avvæpne": "væpne",
    "utladning": "verve",
    "fraskriver": "krav",
    "gi opp": "krav",
    "ubehag": "komfort",
    "koble fra": "koble",
    "misnøye": "innhold",
    "opphør": "videreføring",
    "avvikle": "fortsette",
    "diskontinuitet": "kontinuitet",
    "usammenhengende": "tilkoblet",
    "fraråde": "overtale",
    "motløshet": "oppmuntring",
    "frigjøre": "engasjere",
    "uærlig": "ærlig",
    "uærlighet": "ærlighet",
    "vanære": "ære",
    "desinfisere": "infisere",
    "desintegrerer": "integrere",
    "disjunktiv": "konjunktiv",
    "motvilje": "smak",
    "ulydighet": "lydighet",
    "ulydig": "lyde",
    "lidelse": "rekkefølge",
    "uordentlig": "velordnet",
    "uorganisert": "organisert",
    "misfornøyd": "fornøyd",
    "motbevise": "bevise",
    "diskvalifisere": "kvalifisere",
    "useriøse": "aner",
    "vanry": "anseelse",
    "disrespect": "respekt",
    "respektløs": "ærbødig",
    "utilfredshet": "tilfredshet",
    "dissens": "samtykke",
    "bjørnetjeneste": "service",
    "ulike": "lignende",
    "dissonans": "harmoni",
    "distal": "proksimale",
    "fjern": "lukk",
    "åpen": "lukke",
    "skilles": "utvisket",
    "mistro": "tillit",
    "dagaktive": "nattlig",
    "divergere": "konvergerer",
    "divergens": "konvergens",
    "avvikende": "konvergent",
    "dele opp": "forene",
    "enkeltvis": "multiplisere",
    "delt": "forent",
    "delelig": "udelelig",
    "innenlands": "fremmed",
    "innfødt": "fremmed",
    "dominerende": "underordnet",
    "sovende": "aktiv",
    "utryddet": "bevart",
    "inaktiv": "aktiv",
    "passiv": "aktiv",
    "stille": "støyende",
    "dobbelt": "enkelt",
    "flere": "enkelt",
    "due": "hauk",
    "dramatisk": "tekst",
    "tørke": "våt",
    "sur": "blid",
    "grunn": "utilbørlig",
    "kjedelig": "spisse",
    "flate": "overhead",
    "døende": "begynnende",
    "jordiske": "himmelsk",
    "letthet": "tyngde",
    "lett": "urolig",
    "flo": "tidevann",
    "eksentriske": "konsentriske",
    "utdannet": "uten utdannelse",
    "effektiv": "ineffektiv",
    "effektivitet": "ineffektivitet",
    "egress": "ingress",
    "elastisk": "uelastisk",
    "kvalifisert": "ikke kvalifisert",
    "emosjonelle": "cerebral",
    "empirisk": "teoretisk",
    "tomhet": "fylde",
    "tømme": "full",
    "tynn": "tykne",
    "aktiver": "deaktivere",
    "oppmuntring": "motløshet",
    "slutt": "begynnelse",
    "ending": "begynnelse",
    "midten": "tidlig",
    "endemisk": "cosmopolitan",
    "provinsiell": "cosmopolitan",
    "energisk": "sløv",
    "håndheve": "fritatt",
    "engasjere": "frigjøre",
    "nyt": "lide",
    "tast inn": "exit",
    "lik": "ulik",
    "likestilling": "ulikhet",
    "ekvatoriale": "polar",
    "rettferdig": "urettferdig",
    "viske ut": "ta opp",
    "etablere": "avskaffe",
    "begivenhetsrik": "begivenhetsløs",
    "evergreen": "lauv",
    "utvikling": "devolution",
    "utelukkelse": "inkludering",
    "fritatt": "håndheve",
    "puste ut": "innhalere",
    "eksisterende": "ikke-eksisterende",
    "exit": "tast inn",
    "utvide": "smal",
    "utvidet": "kontrakt",
    "ekspansjon": "kontraksjon",
    "forventet": "uventet",
    "dyrt": "billig",
    "opplevde": "uerfaren",
    "eksport": "import",
    "uttrykke": "lokal",
    "generell": "spesifikk",
    "nasjonal": "internasjonal",
    "forlengelse": "fleksjon",
    "ytre": "interiør",
    "utvendig": "innvendig",
    "eksternt": "internt",
    "slukke": "antennes",
    "ekstramural": "utført",
    "ekstraordinær": "vanlig",
    "extrinsic": "egenverdi",
    "sviktende": "passering",
    "løping": "stående",
    "svikt": "suksess",
    "trofast": "utro",
    "falle": "stige",
    "sett": "stige",
    "feilbarlige": "ufeilbarlig",
    "faller": "stiger",
    "løgn": "sannhet",
    "falskhet": "sannhet",
    "berømmelse": "skjensel",
    "fortrolig": "ukjent",
    "fancy": "vanlig",
    "fett": "tynn",
    "full": "tømme",
    "tykk": "tynn",
    "tykne": "tynn",
    "far": "mor",
    "fauna": "flora",
    "gunstige": "ugunstig",
    "føderal": "enhetlig",
    "hunn": "mann",
    "feminin": "intetkjønn",
    "femininitet": "maskulinitet",
    "fruktbar": "steril",
    "gjengivelse": "utroskap",
    "figur": "bakke",
    "fylle": "tømme",
    "finne": "å tape",
    "bli ferdig": "start",
    "stoppe": "start",
    "avgrenset": "uendelig",
    "brann": "leie",
    "fleksjon": "forlengelse",
    "flyte": "synke",
    "kilde": "synke",
    "flora": "fauna",
    "fokus": "uklarhet",
    "fiende": "venn",
    "brette": "brette",
    "følg": "gå forut for",
    "lykkes": "foregå",
    "tilhenger": "leder",
    "dårskap": "visdom",
    "tullete": "klok",
    "fot": "hode",
    "hale": "hode",
    "forby": "tillate",
    "forgrunnen": "bakgrunn",
    "fremmed": "bekjent",
    "glemme": "huske",
    "forgiving": "uforsonlig",
    "formalisme": "etterligning",
    "heldig": "uheldig",
    "framover": "omvendt",
    "advers": "omvendt",
    "foul": "rettferdig",
    "urettferdig": "rettferdig",
    "funnet": "tapt",
    "broderlig": "identisk",
    "fryse": "kok opp",
    "hyppig": "sjelden",
    "ofte": "sjelden",
    "venn": "fiende",
    "hode": "hale",
    "fylde": "tomhet",
    "funksjonell": "organisk",
    "uorganisk": "organisk",
    "gevinst": "tap",
    "gassformig": "fast",
    "hul": "fast",
    "samle": "spredt",
    "generalitet": "particularity",
    "sjenerøs": "stikkende",
    "pike": "gutt",
    "flink": "ond",
    "godhet": "ondskap",
    "gradvis": "plutselig",
    "takknemlig": "utakknemlig",
    "større": "mindre",
    "grønn": "moden",
    "ekkelt": "nett",
    "bakke": "figur",
    "skyld": "uskyld",
    "skyldig": "uskyldig",
    "gjerne": "dessverre",
    "lykke": "ulykkelighet",
    "lykkelig": "ulykkelig",
    "hardhet": "mykhet",
    "loudness": "mykhet",
    "skarphet": "mykhet",
    "harmoni": "dissonans",
    "hat": "kjærlighet",
    "hatsk": "elskelig",
    "hauk": "due",
    "sunn": "usunn",
    "hørsel": "døv",
    "varme": "kul",
    "himmelsk": "jordiske",
    "heterogenitet": "homogenitet",
    "gjemme seg": "forestilling",
    "leie": "brann",
    "truffet": "gå glipp av",
    "hellig": "profane",
    "homogenitet": "heterogenitet",
    "homolog": "analogt",
    "homoseksuell": "biseksuell",
    "ærlig": "uærlig",
    "ærlighet": "uærlighet",
    "ære": "vanære",
    "håp": "desperasjon",
    "håpe": "håpløs",
    "håpløs": "håpe",
    "horisontal": "vertikal",
    "fiendtlig": "vennlig",
    "uvennlig": "snill",
    "varmt": "kald",
    "ydmyk": "stolt",
    "ydmykhet": "stolthet",
    "sulten": "tørst",
    "identisk": "broderlig",
    "tomgang": "arbeid",
    "vulkanske": "vandig",
    "antennes": "slukke",
    "overse": "legge merke til",
    "ulovlig": "lovlig",
    "ulovlighet": "lovligheten",
    "uleselige": "leselig",
    "ulogisk": "logisk",
    "etterligning": "formalisme",
    "uvesentlig": "materiale",
    "umodenhet": "modenhet",
    "grenseløs": "målbar",
    "umoralsk": "moralsk",
    "umoral": "moral",
    "udødelig": "mortal",
    "udødelighet": "dødelighet",
    "uforanderlige": "foranderlig",
    "habilitet": "partiskhet",
    "uframkommelig": "farbar",
    "utålmodighet": "tålmodighet",
    "utålmodig": "pasient",
    "umerkelig": "merkbar",
    "ufullkommenhet": "fullkommenhet",
    "ugjennomtrengelig": "gjennomtrengelig",
    "utillatelig": "tillatelig",
    "upersonlig": "personlig",
    "uhøflig": "høflig",
    "import": "eksport",
    "viktig": "uviktig",
    "umulighet": "mulighet",
    "impotent": "mektig",
    "usannsynlig": "sannsynlig",
    "forbedret": "uforbedret",
    "forbedring": "avslå",
    "uklok": "forsvarlig",
    "urenhet": "renhet",
    "manglende evne": "evnen",
    "utilgjengelig": "tilgjengelig",
    "unøyaktig": "korrekt",
    "passivitet": "handling",
    "inaktivitet": "aktivitet",
    "utilstrekkelig": "tilstrekkelig",
    "ikke godtas": "tillatelig",
    "livløse": "animere",
    "uoppmerksomhet": "oppmerksomhet",
    "uhørlig": "hørbar",
    "ikke i stand til": "i stand",
    "uførhet": "kapasitet",
    "tilbøyelig": "horisontal",
    "vertikal": "horisontal",
    "inkludering": "utelukkelse",
    "uforenlig": "kompatibel",
    "inkompetanse": "kompetanse",
    "inkompetent": "kompetent",
    "ufullstendighet": "fullstendighet",
    "hensynsløs": "hensyns",
    "inkonsekvens": "konsistens",
    "upraktisk": "beleilig",
    "øke": "avta",
    "økt": "redusert",
    "tilvekst": "minsk",
    "uhelbredelig": "herdbart",
    "uanstendighet": "anstendighet",
    "uanstendig": "skikkelig",
    "ubesluttsomhet": "beslutning",
    "ubesluttsom": "avgjørende",
    "uavhengig": "avhengig",
    "utvisket": "skilles",
    "udelelig": "delelig",
    "innendørs": "utendørs",
    "ineffektiv": "effektiv",
    "ineffektivitet": "effektivitet",
    "uelastisk": "elastisk",
    "ikke kvalifisert": "kvalifisert",
    "ulikhet": "likestilling",
    "uerfaren": "opplevde",
    "ufeilbarlig": "feilbarlige",
    "skjensel": "berømmelse",
    "infisere": "desinfisere",
    "mindreverdig": "overlegen",
    "underlegenhet": "overlegenhet",
    "utroskap": "gjengivelse",
    "uendelig": "avgrenset",
    "inflasjon": "deflasjon",
    "informert": "uinformert",
    "sjelden": "ofte",
    "ingress": "egress",
    "bebodd": "ubebodd",
    "innhalere": "puste ut",
    "urettferdighet": "rettferdighet",
    "inn i landet": "kyst",
    "uskyld": "skyld",
    "uskyldig": "skyldig",
    "ufarlige": "skadelig",
    "virkningsløs": "operative",
    "sinnsyk": "tilregnelig",
    "galskap": "tilregnelighet",
    "usikkerhet": "sikkerhet",
    "ubetydelighet": "betydning",
    "ubetydelig": "betydelige",
    "uoppløselig": "løselig",
    "insolvens": "solvens",
    "insolvent": "løsemiddel",
    "ustabilitet": "stabilitet",
    "instrumental": "vokal",
    "insuffisiens": "forsyning",
    "integrere": "desintegrerer",
    "integrering": "segregering",
    "intelligens": "dumhet",
    "forståelig": "uforståelig",
    "tiltenkt": "utilsiktet",
    "med hensikt": "utilsiktet",
    "interessert": "uinteressert",
    "interessant": "uinteressant",
    "interiør": "ytre",
    "mellomliggende": "terminal",
    "innvendig": "utvendig",
    "internt": "eksternt",
    "internasjonal": "nasjonal",
    "lokal": "generell",
    "intoleranse": "toleranse",
    "intolerant": "tolerant",
    "intraktabel": "medgjørlig",
    "utført": "ekstramural",
    "egenverdi": "extrinsic",
    "usynlighet": "synlighet",
    "usynlig": "synlig",
    "ufrivillig": "frivillig",
    "irrasjonell": "rasjonell",
    "uregelmessig": "regelmessig",
    "uregelmessighet": "regelmessighet",
    "irrelevant": "aktuell",
    "uansvarlig": "ansvarlig",
    "utgave": "minnes",
    "ledd": "skille",
    "glede": "sorg",
    "gledelig": "sorgfull",
    "junior": "senior",
    "rettferdighet": "urettferdighet",
    "ungdoms-": "voksen",
    "kern": "kern",
    "snill": "uvennlig",
    "konge": "dronning",
    "lekfolket": "geistlige",
    "sent": "tidlig",
    "latter": "gråte",
    "lovlig": "ulovlig",
    "lax": "anspent",
    "avslappet": "anspent",
    "lekmann": "prest",
    "lede": "underskudd",
    "leder": "tilhenger",
    "permisjon": "ankomme",
    "venstre": "senter",
    "lovligheten": "ulovlighet",
    "legalisere": "fredløs",
    "leselig": "uleselige",
    "utlåner": "låner",
    "forlenge": "forkorte",
    "mindre": "større",
    "sløv": "energisk",
    "nivå": "heve",
    "nedre": "heve",
    "liberal": "konservative",
    "å ligge": "stå",
    "utbytte": "stå",
    "lys": "mørk",
    "smak": "smakløs",
    "begrenset": "ubegrenset",
    "lineær": "sikkerhet",
    "væske": "gassformig",
    "fast": "hul",
    "spesifikk": "generell",
    "plassering": "studio",
    "låse": "låse opp",
    "lodge": "løsne",
    "logisk": "ulogisk",
    "lang": "kort",
    "høy": "kort",
    "å tape": "finne",
    "tap": "gevinst",
    "tapt": "funnet",
    "elskelig": "hatsk",
    "kjærlighet": "hat",
    "tekst": "dramatisk",
    "major": "liten",
    "flertall": "entall",
    "gjøre": "gå i stykker",
    "reparere": "gå i stykker",
    "mann": "hunn",
    "malign": "godartet",
    "ondartet": "godartet",
    "håndbok": "automatisk",
    "merket": "umerket",
    "gift": "ugift",
    "maskulin": "feminin",
    "intetkjønn": "feminin",
    "maskulinitet": "femininitet",
    "maske": "avsløre",
    "materiale": "uvesentlig",
    "mors": "fars",
    "modenhet": "umodenhet",
    "maksimum": "minimum",
    "målbar": "grenseløs",
    "mental": "fysisk",
    "barmhjertig": "nådeløs",
    "nådeløs": "barmhjertig",
    "militær": "sivil",
    "sinn": "glemme",
    "huske": "glemme",
    "minimum": "maksimum",
    "liten": "stor",
    "minoritet": "flertall",
    "misforståelse": "oppfatning",
    "gå glipp av": "truffet",
    "jeksel": "molekyl~~pos=trunc",
    "molekyl~~pos=trunc": "jeksel",
    "moralsk": "umoralsk",
    "moral": "umoral",
    "mortal": "udødelig",
    "dødelighet": "udødelighet",
    "mor": "far",
    "multiplisere": "enkeltvis",
    "forene": "dele opp",
    "nadir": "zenith",
    "smal": "utvide",
    "begynnende": "døende",
    "negativ": "nøytral",
    "forsømmelig": "flittig",
    "nevø": "niese",
    "nett": "ekkelt",
    "niese": "nevø",
    "natt": "dag",
    "nattlig": "dagaktive",
    "nominell": "ekte",
    "uvirkelig": "ekte",
    "ikke-eksisterende": "eksisterende",
    "normal": "unormal",
    "legge merke til": "overse",
    "skadelig": "ufarlige",
    "numerisk": "verbal",
    "lydighet": "ulydighet",
    "lydig": "ulydig",
    "lyde": "ulydig",
    "objektiv": "subjektiv",
    "obligatorisk": "valgfri",
    "skrå": "vinkelrett",
    "opasitet": "åpenhet",
    "okkupert": "ledig",
    "fornærmelse": "forsvar",
    "støtende": "defensiv",
    "offisielt": "uoffisiell",
    "operative": "virkningsløs",
    "motsetning": "uten motstand",
    "motsatte": "alternere",
    "optimisme": "pessimisme",
    "optimist": "pessimist",
    "valgfri": "obligatorisk",
    "muntlig": "skrevet",
    "rekkefølge": "lidelse",
    "velordnet": "uordentlig",
    "vanlig": "uvanlig",
    "organisk": "uorganisk",
    "organisert": "uorganisert",
    "ortodoks": "uortodokse",
    "utendørs": "innendørs",
    "fredløs": "legalisere",
    "overvurdere": "undervurder",
    "overhead": "flate",
    "overt": "skjult",
    "pakke": "pakke ut",
    "smertefull": "smertefri",
    "smertefri": "smertefull",
    "parallell": "skrå",
    "vinkelrett": "skrå",
    "forelder": "barn",
    "partiskhet": "habilitet",
    "particularity": "generalitet",
    "til dels": "helt",
    "farbar": "uframkommelig",
    "passering": "løping",
    "stående": "løping",
    "forbi": "framtid",
    "nåværende": "fraværende",
    "fars": "mors",
    "tålmodighet": "utålmodighet",
    "pasient": "utålmodig",
    "nedlatende": "boikott",
    "fred": "krig",
    "straff": "belønning",
    "merkbar": "umerkelig",
    "fullkommenhet": "ufullkommenhet",
    "gjennomtrengelig": "ugjennomtrengelig",
    "givende": "forebyggende",
    "tillate": "forby",
    "personlig": "upersonlig",
    "overtale": "fraråde",
    "pessimisme": "optimisme",
    "pessimist": "optimist",
    "fysisk": "mental",
    "saksøker": "anklagede",
    "hyggelig": "ubehagelig",
    "fornøyd": "misfornøyd",
    "polar": "ekvatoriale",
    "høflig": "uhøflig",
    "populær": "upopulær",
    "porøsitet": "soliditet",
    "mulighet": "umulighet",
    "posterior": "anterior",
    "mektig": "impotent",
    "potensial": "faktiske",
    "fattigdom": "rikdom",
    "kraftig": "maktesløs",
    "maktesløs": "kraftig",
    "ros": "kritisere",
    "gå forut for": "lykkes",
    "foregå": "lykkes",
    "prefiks": "suffiks",
    "forberedelse": "vedtak",
    "forberedt": "uforberedt",
    "normative": "beskrivende",
    "tilstedeværelse": "fravær",
    "forebyggende": "givende",
    "hoved~~pos=trunc": "sekundær",
    "privat": "offentlig",
    "sannsynlig": "usannsynlig",
    "produktivt": "uproduktive",
    "profane": "hellig",
    "profesjonell": "amatør",
    "framgang": "regress",
    "progressive": "regressive",
    "prospektive": "retrospektiv",
    "beskyttet": "ubeskyttet",
    "stolt": "ydmyk",
    "bevise": "motbevise",
    "proksimale": "distal",
    "plassen": "ultimat",
    "forsvarlig": "uklok",
    "offentlig": "privat",
    "publisert": "upublisert",
    "dra": "trykk",
    "punktlighet": "tardiness",
    "purge": "rehabilitere",
    "renhet": "urenhet",
    "trykk": "dra",
    "kvalifisere": "diskvalifisere",
    "dronning": "konge",
    "spørsmål": "svar",
    "tvilsom": "udiskutable",
    "raskt": "sakte",
    "heve": "nedre",
    "rasjonell": "irrasjonell",
    "ekte": "uvirkelig",
    "realistisk": "urealistisk",
    "forsikre": "bekymre",
    "minnes": "utgave",
    "ta opp": "viske ut",
    "nekte": "aksepterer",
    "regress": "framgang",
    "regressive": "progressive",
    "regelmessig": "uregelmessig",
    "regelmessighet": "uregelmessighet",
    "regulert": "uregulert",
    "rehabilitere": "purge",
    "avvisning": "godkjennelse",
    "forynge": "alder",
    "i slekt": "urelatert",
    "slektning": "absolutte",
    "aktuell": "irrelevant",
    "pålitelig": "upålitelig",
    "religiøs": "sekulære",
    "frastøting": "tiltrekning",
    "aner": "useriøse",
    "anseelse": "vanry",
    "motstå": "overgivelse",
    "vedtak": "forberedelse",
    "respekt": "respektløs",
    "ansvarlig": "uansvarlig",
    "behersket": "hemningsløs",
    "retrospektiv": "prospektive",
    "ærbødig": "respektløs",
    "reversering": "bekreftelse",
    "belønning": "straff",
    "ri": "gå",
    "moden": "grønn",
    "stiger": "faller",
    "rotoren": "stator",
    "ruhet": "glatthet",
    "rund": "torget",
    "avrundet": "vinkel",
    "landlig": "urban",
    "skynde": "dvele",
    "dessverre": "gjerne",
    "tristhet": "lykke",
    "ulykkelighet": "lykke",
    "sikker": "farlig",
    "likhet": "forskjell",
    "tilregnelig": "sinnsyk",
    "tilregnelighet": "galskap",
    "tilfredshet": "utilfredshet",
    "velsmakende": "smakløs",
    "knapp": "rikelig",
    "knapphet": "overflod",
    "vitenskapelig": "uvitenskapelig",
    "samvittighetsfull": "samvittighetsløs",
    "sekundær": "hoved~~pos=trunc",
    "sekulære": "religiøs",
    "segregering": "integrering",
    "selvopptatt": "uselvisk",
    "selge": "kjøpe",
    "senior": "junior",
    "skille": "ledd",
    "atskillelse": "union",
    "septisk": "antiseptisk middel",
    "service": "bjørnetjeneste",
    "bosatte seg": "uoppgjorte",
    "spisse": "flate",
    "kort": "høy",
    "forkorte": "forlenge",
    "rope": "hviske",
    "forestilling": "gjemme seg",
    "krympe": "tøye ut",
    "side": "bunn",
    "topp": "bunn",
    "betydning": "ubetydelighet",
    "betydelige": "ubetydelig",
    "lignende": "ulike",
    "enkel": "forbindelse",
    "forenkle": "komplisere",
    "enkelt": "flere",
    "entall": "flertall",
    "synke": "kilde",
    "søster": "bror",
    "sove": "våkne",
    "sakte": "raskt",
    "glatthet": "ruhet",
    "mykhet": "skarphet",
    "soliditet": "porøsitet",
    "løselig": "uoppløselig",
    "solvens": "insolvens",
    "løsemiddel": "insolvent",
    "sønn": "datter",
    "sorg": "glede",
    "sorgfull": "gledelig",
    "uskreven": "skrevet",
    "sporadisk": "kontinuerlig",
    "spredt": "samle",
    "torget": "rund",
    "stabilitet": "ustabilitet",
    "stabil": "ustabil",
    "stå": "utbytte",
    "start": "stoppe",
    "stator": "rotoren",
    "oppholde seg": "bevege seg",
    "stødig": "ustødig",
    "bratt": "gradvis",
    "plutselig": "gradvis",
    "steril": "fruktbar",
    "stive": "løsne",
    "stikkende": "sjenerøs",
    "storm-": "rolig",
    "rett": "krummet",
    "rette": "bøye",
    "styrke": "svakhet",
    "tøye ut": "krympe",
    "sterk": "svakt",
    "studio": "plassering",
    "dumhet": "intelligens",
    "subjektiv": "objektiv",
    "underordnet": "dominerende",
    "senere": "forutgående",
    "materielle": "adjektiv",
    "trekke fra": "legg til",
    "subtraksjon": "addisjon",
    "suksess": "svikt",
    "vellykket": "mislykket",
    "bukke": "overleve",
    "lide": "nyt",
    "forsyning": "kreve",
    "suffiks": "prefiks",
    "soloppgang": "solnedgang",
    "solnedgang": "soloppgang",
    "overlegen": "mindreverdig",
    "overlegenhet": "underlegenhet",
    "støttet": "støttes",
    "overgivelse": "motstå",
    "overleve": "bukke",
    "søt": "sur",
    "våt": "tørke",
    "blid": "sur",
    "symmetri": "asymmetri",
    "medfølende": "usympatiske",
    "synergistisk": "antagonistisk",
    "syntese": "analyse",
    "syntetisk": "analytisk",
    "tardiness": "punktlighet",
    "smakløs": "velsmakende",
    "mør": "vanskelig",
    "anspent": "avslappet",
    "terminal": "mellomliggende",
    "teisme": "ateisme",
    "teoretisk": "empirisk",
    "tørst": "sulten",
    "omtenksom": "tankeløs",
    "tankeløs": "omtenksom",
    "sparsommelig": "uøkonomisk",
    "tidevann": "flo",
    "slips": "knytte opp",
    "sjenert": "dristig",
    "fryktsomhet": "dristighet",
    "toleranse": "intoleranse",
    "tolerant": "intolerant",
    "tann": "tannløs",
    "tannløs": "tann",
    "berørt": "urørt",
    "medgjørlig": "intraktabel",
    "tragedie": "komedie",
    "trent": "utrent",
    "tillit": "mistro",
    "sannhet": "falskhet",
    "stygghet": "skjønnhet",
    "stygg": "vakker",
    "ultimat": "plassen",
    "uakseptabelt": "akseptabel",
    "besvares": "anerkjente",
    "uendret": "endret",
    "entydig": "tvetydig",
    "ubevæpnet": "bevæpnet",
    "uautorisert": "autorisert",
    "ubalansert": "balanserte",
    "vantro": "tro",
    "ubundet": "bundet",
    "uknuselig": "knuselig",
    "ubrutt": "gått i stykker",
    "uforanderlig": "foranderlig",
    "onkel": "tante",
    "uvanlig": "vanlig",
    "likegyldig": "bekymret",
    "ubekreftet": "bekreftet",
    "bevisstløshet": "bevissthet",
    "grunnlovsstridig": "konstitusjonell",
    "ukonvensjonell": "konvensjonell",
    "avdekke": "slør",
    "uncut": "kutte opp",
    "udefinert": "definert",
    "undervurder": "overvurdere",
    "uønsket": "ønskelig",
    "utilbørlig": "grunn",
    "uten utdannelse": "utdannet",
    "utvetydig": "tvetydig",
    "begivenhetsløs": "begivenhetsrik",
    "uventet": "forventet",
    "utro": "trofast",
    "ukjent": "fortrolig",
    "ugunstig": "gunstige",
    "uforsonlig": "forgiving",
    "uheldig": "heldig",
    "utakknemlig": "takknemlig",
    "ulykkelig": "lykkelig",
    "usunn": "sunn",
    "uhellig": "hellig",
    "uviktig": "viktig",
    "uforbedret": "forbedret",
    "uinformert": "informert",
    "ubebodd": "bebodd",
    "uforståelig": "forståelig",
    "utilsiktet": "med hensikt",
    "uinteressert": "interessert",
    "uinteressant": "interessant",
    "union": "atskillelse",
    "enhetlig": "føderal",
    "forent": "delt",
    "ubegrenset": "begrenset",
    "låse opp": "låse",
    "umerket": "merket",
    "ugift": "gift",
    "avsløre": "maske",
    "ledig": "okkupert",
    "uoffisiell": "offisielt",
    "uten motstand": "motsetning",
    "uortodokse": "ortodoks",
    "pakke ut": "pakke",
    "upopulær": "populær",
    "uforberedt": "forberedt",
    "uproduktive": "produktivt",
    "ubeskyttet": "beskyttet",
    "upublisert": "publisert",
    "udiskutable": "tvilsom",
    "urealistisk": "realistisk",
    "uregulert": "regulert",
    "urelatert": "i slekt",
    "upålitelig": "pålitelig",
    "hemningsløs": "behersket",
    "usmakelig": "velsmakende",
    "uvitenskapelig": "vitenskapelig",
    "samvittighetsløs": "samvittighetsfull",
    "uselvisk": "selvopptatt",
    "uoppgjorte": "bosatte seg",
    "ustabil": "stabil",
    "ustødig": "stødig",
    "mislykket": "vellykket",
    "støttes": "støttet",
    "usympatiske": "medfølende",
    "knytte opp": "slips",
    "urørt": "berørt",
    "utrent": "trent",
    "uforsiktige": "skeptisk",
    "uvillig": "villig",
    "uvilje": "villighet",
    "koble av": "vind",
    "uverdig": "verdig",
    "urban": "landlig",
    "verdifull": "verdiløs",
    "slør": "avdekke",
    "verbal": "numerisk",
    "seier": "nederlag",
    "dydig": "ond",
    "synlighet": "usynlighet",
    "synlig": "usynlig",
    "vokal": "konsonant",
    "frivillig": "ufrivillig",
    "våkne": "sove",
    "gå": "ri",
    "blekne": "voks",
    "krig": "fred",
    "skeptisk": "uforsiktige",
    "avfall": "spare",
    "uøkonomisk": "sparsommelig",
    "voks": "blekne",
    "svakt": "sterk",
    "svakhet": "styrke",
    "rikdom": "fattigdom",
    "vektløs": "tungtveiende",
    "tungtveiende": "vektløs",
    "hviske": "rope",
    "hvit": "svart",
    "helt": "til dels",
    "bred": "smal",
    "villig": "uvillig",
    "villighet": "uvilje",
    "vind": "koble av",
    "visdom": "dårskap",
    "klok": "tullete",
    "ta ut": "innskudd",
    "bekymre": "forsikre",
    "verdiløs": "verdifull",
    "verdig": "uverdig",
    "skrevet": "uskreven",
    "ung": "aldrende",
    "zenith": "nadir",
}



"""
Created on Wed Aug 25 14:07:11 2021

@author: alfonso
"""

_negations = {
    "german": ["nicht", "nein"],
    "english": [
        "no",
        "neither",
        "not",
        "cannot",
        "never",
        "can't",
        "won't",
        "nothing",
        "don't",
        "doesn't",
        "didn't",
        "n't",
    ],
    "italian": ["non", "no", "né"],
    "french": ["non", "pas", "ne"],
    "danish": ["nej", "ikke"],
    "dutch": ["nee", "niet"],
    "catalan": ["no", "tampoc"],
    "chinese": ["都不是", "不"],
    "greek": ["δεν", "ούτε", "όχι"],
    "japanese": ["いいえ"],
    "lituanian": ["ne", "nei"],
    "macedonian": ["не", "ниту"],
    "norvegian": ["ikke", "nei"],
    "polish": ["nie", "ani"],
    "portuguese": ["não", "nem"],
    "romanian": ["nu", "nici"],
    "russian": ["нет", "ни"],
    "spanish": ["no", "ni"],
}

_pronouns = {
    "german": [
        "dir",
        "mich",
        "es",
        "ihnen",
        "unser",
        "uns",
        "wir",
        "euer",
        "sein",
        "sie",
        "du",
        "mein",
        "er",
        "dein",
        "euch",
        "dich",
        "ihr",
        "ich",
        "mir",
        "ihn",
        "ihm",
        "sich",
    ],
    "english": [
        "he",
        "his",
        "we",
        "her",
        "them",
        "i",
        "it",
        "they",
        "me",
        "us",
        "you",
        "she",
    ],
    "italian": [
        "ella",
        "esso",
        "io",
        "te",
        "lei",
        "egli",
        "vi",
        "voi",
        "tu",
        "noi",
        "essa",
        "lui",
        "essi",
        "ci",
        "me",
        "loro",
    ],
    "french": ["ils", "elle", "elles", "il", "on", "tu", "vous", "nous", "je"],
    "danish": ["de", "hun", "han", "vi", "jeg", "i", "du"],
    "dutch": ["jullie", "u", "ik", "jij", "zij", "hij", "wij"],
    "catalan": [
        "jo",
        "ella",
        "nosaltres",
        "ells",
        "vós",
        "tu",
        "vos",
        "vosaltres",
        "el",
    ],
    "chinese": [
        "您",
        "你们",
        "我",
        "他们",
        "它",
        "你",
        "它们",
        "我们",
        "她们",
        "咱们",
        "她",
        "他",
    ],
    "greek": [
        "εσείς",
        "αυτος",
        "αυτά",
        "eγώ",
        "αυτή",
        "αυτη",
        "αυτα",
        "αυτο",
        "αυτοι",
        "εμείς",
        "αυτοί",
        "αυτός",
        "αυτες",
        "εσύ",
    ],
    "japanese": [
        "僕",
        "私",
        "我々",
        "彼",
        "俺",
        "おれ",
        "方",
        "お前",
        "彼女",
        "かのじょ",
        "貴方",
        "あのひと",
        "あなた",
        "あの人",
        "私達",
        "君",
        "ぼく",
        "わたし",
        "おまえ",
        "かれ",
        "きみ",
    ],
    "lituanian": [
        "jóms",
        "jám",
        "tavyjè",
        "tavimì",
        "noi",
        "mùms",
        "jùs",
        "manè",
        'jiẽ", "essi',
        "jomìs",
        "mán",
        "jū̃s",
        "mùs",
        "mumysè",
        "mẽs",
        "jumìs",
        "jùms",
        "juosè",
        "jaĩs",
        "jõs",
        "jái",
        "jumysè",
        "jį̃",
        "mumìs",
        "josè",
        "mū́sų",
        "jojè",
        "jàs",
        "juõs",
        "jà",
        "j¡ems",
        "voi",
        "táu",
        "tavè",
        "esse",
        "juõ",
        "manimì",
        "ją̃",
        "jū́sų",
        "jamè",
        "jų̃",
        "manyjè",
    ],
    "macedonian": ["ти", "јас", "таа", "тие", "вие", "ние", "тој"],
    "norvegian": [
        "de",
        "hun",
        "han",
        "henne",
        "dem",
        "han, ham",
        "seg",
        "det",
        "vi",
        "jeg",
        "dere",
        "deg",
        "den",
        "oss",
        "meg",
        "du",
    ],
    "polish": ["wy", "on", "ja", "my", "ty", "ona", "oni", "pan"],
    "portuguese": ["nós", "vós", "elas", "eu", "ele", "tu", "eles", "ela"],
    "romanian": [
        "dumneaei",
        "ei",
        "eu",
        "ele",
        "dvs",
        "voi",
        "tu",
        "dumnealui",
        "noi",
        "dumnealor",
        "dumneavoastră",
        "ea",
        "el",
    ],
    "russian": [
        "o ней",
        "онa",
        "ими",
        "мне",
        "вами",
        "них",
        "нами",
        "ему",
        "тебе",
        "нам",
        "o вас",
        "её",
        "вас",
        "ей",
        "они",
        "o нас",
        "его",
        "я",
        "меня",
        "oбo мне",
        "тобой",
        "него",
        "ты",
        "тебя",
        "неё",
        "вам",
        "он/оно",
        "их",
        "o нём",
        "вы",
        "нас",
        "мы",
        "o тебe",
        "мной",
        "им",
        "о них",
    ],
    "spanish": [
        "ella",
        "vosotros",
        "vosotras",
        "las",
        "usted",
        "los",
        "nos",
        "vusted",
        "te",
        "yo",
        "le",
        "ellos",
        "vustedes",
        "os",
        "nosotros",
        "vuecencia",
        "vuecencias",
        "ustedes",
        "les",
        "ello",
        "nosotras",
        "vusías",
        "ellas",
        "me",
        "la",
        "tú",
        "se",
        "lo",
        "vusía",
        "él",
    ],
}


def _valences(language):

    if language == "catalan":
        from valence.catalan import _positive, _negative, _ambivalent

    elif language == "chinese":
        from valence.chinese import _positive, _negative, _ambivalent

    elif language == "danish":
        from valence.danish import _positive, _negative, _ambivalent

    elif language == "dutch":
        from valence.dutch import _positive, _negative, _ambivalent

    elif language == "english":
        from valence.english import _positive, _negative, _ambivalent

    elif language == "french":
        from valence.french import _positive, _negative, _ambivalent

    elif language == "german":
        from valence.german import _positive, _negative, _ambivalent

    elif language == "greek":
        from valence.greek import _positive, _negative, _ambivalent

    elif language == "italian":
        from valence.italian import _positive, _negative, _ambivalent

    elif language == "japanese":
        from valence.japanese import _positive, _negative, _ambivalent

    elif language == "lithuanian":
        from valence.lithuanian import _positive, _negative, _ambivalent

    elif language == "norwegian":
        from valence.norwegian import _positive, _negative, _ambivalent

    elif language == "polish":
        from valence.polish import _positive, _negative, _ambivalent

    elif language == "portuguese":
        from valence.portuguese import _positive, _negative, _ambivalent

    elif language == "romanian":
        from valence.romanian import _positive, _negative, _ambivalent

    elif language == "russian":
        from valence.russian import _positive, _negative, _ambivalent

    elif language == "spanish":
        from valence.spanish import _positive, _negative, _ambivalent

    elif language == "macedonian":
        from valence.macedonian import _positive, _negative, _ambivalent

    return _positive, _negative, _ambivalent


def _language_code3(language):

    missing = ["russian", "macedonian", "german"]
    if language in missing:
        return None

    if language == "chinese":
        return "cmn"
    if language == "greek":
        return "ell"
    if language == "norwegian":
        return "nno"
    if language == "romanian":
        return "ron"
    if language == "japanese":
        return "jpn"
    if language == "dutch":
        return "nld"
    if language == "french":
        return "fra"

    ok_lang = [
        "catalan",
        "danish",
        "spanish",
        "italian",
        "polish",
        "english",
        "lithuanian",
        "portuguese",
    ]
    if language in ok_lang:
        return language[:3]

    return None


def _check_language(language):

    # Check for language
    try:
        allowed_languages = [
            "catalan",
            "chinese",
            "danish",
            "dutch",
            "english",
            "french",
            "german",
            "greek",
            "japanese",
            "italian",
            "lithuanian",
            "macedonian",
            "norwegian",
            "polish",
            "portuguese",
            "romanian",
            "russian",
            "spanish",
        ]
        assert language in allowed_languages
    except:
        raise ValueError(
            "'{}' is not allowed as a language. Please specify a language among '{}'.".format(
                language, "', '".join(allowed_languages)
            )
        )

    return


def _language_correction_tokens(token, language):
    if language == "italian":
        if "'" in token:
            return token.split("'")[1]
    return token


def _language_correction_text(text, language):
    if language == "italian":
        return text.replace("'", "o ")
    return text



_antonyms = {
    "umiejętność": "niemożność",
    "nieprawidłowy": "normalna",
    "znieść": "ustalić",
    "brak": "obecność",
    "nieobecny": "obecny",
    "przyszłość": "przeszłość",
    "absolutny": "krewny",
    "wstrzymać się": "konsumować",
    "abstrakcyjny": "beton",
    "obfitość": "niedostatek",
    "obfity": "deficytowy",
    "zaakceptować": "odrzucać",
    "przyznać": "zaprzeczać",
    "do przyjęcia": "gorszący",
    "przyjęcie": "odmowa",
    "dostępny": "niedostępny",
    "dokładny": "niedokładny",
    "potwierdzone": "niepotwierdzony",
    "znajomy": "nieznany",
    "działać": "refren",
    "akcja": "bezczynność",
    "aktywny": "cichy",
    "pozostały": "wyginąć",
    "głośny": "cichy",
    "czynność": "bezczynność",
    "rzeczywisty": "potencjał",
    "dodaj": "odejmować",
    "dodanie": "odejmowanie",
    "odpowiedni": "niewystarczający",
    "przymiotnik": "rzeczownik",
    "dopuszczalny": "niedopuszczalny",
    "dorosły": "nieletni",
    "postęp": "regres",
    "przed siebie": "plecy",
    "z przodu": "tylny",
    "skręcać": "plecy",
    "korzyść": "niekorzyść",
    "afirmacja": "odwrócenie",
    "twierdzący": "negatywny",
    "neutralny": "negatywny",
    "na rufie": "dziobowy",
    "wiek": "odmładzać",
    "w wieku": "młody",
    "podniecenie": "spokój",
    "zgodzić się": "nie zgadzać się",
    "przyjemny": "nieprzyjemny",
    "umowa": "niezgoda",
    "zmieniony": "niezmieniony",
    "alternatywny": "naprzeciwko",
    "amator": "profesjonalny",
    "dwuznaczny": "jednoznaczny",
    "przyjazny": "nieprzyjazny",
    "ziemnowodny": "ziemski",
    "analny": "doustny",
    "analogiczny": "homologiczny",
    "analiza": "synteza",
    "analityczny": "syntetyczny",
    "przodek": "potomek",
    "kątowy": "bułczasty",
    "animować": "nieożywiony",
    "odpowiedź": "pytanie",
    "antagonistyczny": "synergistyczny",
    "poprzednik": "kolejny",
    "poprzedni": "tylny",
    "antyseptyczny": "septyczny",
    "wygląd": "zanik",
    "uznanie": "deprecjacja",
    "zatwierdzenie": "dezaprobata",
    "zatwierdzać": "potępiać",
    "wodny": "ogniowy",
    "ziemski": "niebiański",
    "ramię": "rozbrajać",
    "uzbrojony": "bezbronny",
    "przybyć": "pozostawiać",
    "wspiąć się": "schodzić",
    "wzlot": "zejście",
    "we śnie": "obudzić",
    "zgoda": "bunt",
    "asymetria": "symetria",
    "ateizm": "teizm",
    "dołączać": "odłączyć",
    "atak": "bronić",
    "zaskarżyć": "bronić",
    "uwaga": "nieuwaga",
    "atrakcja": "odpychanie",
    "słyszalny": "niesłyszalny",
    "powiększenie": "zmniejszenie",
    "ciocia": "wujek",
    "upoważniony": "nieautoryzowany",
    "automatyczny": "podręcznik",
    "uniknąć": "konfrontować",
    "obudzić": "we śnie",
    "plecy": "skręcać",
    "oddalać się": "postęp",
    "tylny": "poprzedni",
    "tło": "pierwszoplanowy",
    "do tyłu": "naprzód",
    "rewers": "awers",
    "zły": "dobry",
    "zło": "dobry",
    "niegodziwość": "dobroć",
    "zrównoważony": "niezrównoważony",
    "niedźwiedź": "byk",
    "piękny": "brzydki",
    "piękno": "brzydota",
    "zaczynać": "koniec",
    "początek": "zatrzymać",
    "wcześnie": "późno",
    "wiara": "niewiara",
    "zakręt": "wyprostować",
    "łagodny": "złośliwy",
    "duży": "mały",
    "narodziny": "śmierć",
    "biseksualny": "homoseksualny",
    "czarny": "biały",
    "błogosławić": "przekleństwo",
    "błogosławiony": "przeklęty",
    "bezkrwawy": "krwawy",
    "krwawy": "bezkrwawy",
    "plama": "skupiać",
    "gotować": "zamrażać",
    "pogrubienie": "nieśmiały",
    "śmiałość": "nieśmiałość",
    "pożyczać": "wypożyczać",
    "pożyczający": "pożyczający",
    "dolny": "top",
    "granica": "rozwiązany",
    "chłopak": "dziewczyna",
    "bojkot": "patronować",
    "przerwa": "naprawa",
    "łamliwy": "niezniszczalny",
    "rozjaśnić": "zaciemniać",
    "złamany": "nieprzerwany",
    "brat": "siostra",
    "byk": "niedźwiedź",
    "zajęty": "wolny",
    "praca": "bezczynny",
    "kupować": "sprzedać",
    "spokojna": "burzliwy",
    "spokój": "podniecenie",
    "zdolny": "niezdolny",
    "pojemność": "nieudolność",
    "gotówka": "kredyt",
    "obciążyć": "kredyt",
    "centrum": "lewo",
    "mózgowy": "emocjonalny",
    "pewność": "niepewność",
    "zmiana": "zostać",
    "odstąpić": "zostać",
    "ruszaj się": "zostać",
    "zmienny": "niezmienny",
    "zmienione": "niezmienione",
    "opłata": "rozładować się",
    "zwerbować": "rozładować się",
    "tani": "kosztowny",
    "dopingować": "skarżyć się",
    "wesoły": "przygnębiający",
    "dziecko": "rodzic",
    "cywil": "wojskowy",
    "roszczenie": "utracić",
    "przejrzystość": "nieprzezroczystość",
    "rozgłos": "zapomnienie",
    "przezroczystość": "nieprzezroczystość",
    "czysty": "nieczysty",
    "kler": "laicy",
    "duchowny": "laik",
    "blisko": "otwarty",
    "zamknięte": "otwarty",
    "zamknąć": "otwarty",
    "bliskość": "otwartość",
    "przybrzeżny": "śródlądowy",
    "zgodny": "wyzywający",
    "zimno": "gorąco",
    "dodatkowy": "liniowy",
    "komedia": "tragedia",
    "komfort": "niewygoda",
    "pospolity": "niezwykły",
    "kompetencja": "niekompetencja",
    "kompetentny": "niekompetentny",
    "zawody": "współpraca",
    "skarżyć się": "dopingować",
    "kompletność": "niekompletność",
    "złożony": "prosty",
    "komplikować": "uproszczać",
    "wklęsły": "wypukły",
    "zarozumiałość": "pokora",
    "duma": "pokora",
    "stężenie": "dystrybucja",
    "koncentryczny": "ekscentryczny",
    "koncepcja": "nieporozumienie",
    "zaniepokojony": "obojętny",
    "beton": "abstrakcyjny",
    "zatwardziały": "niepotwierdzony",
    "konfrontować": "uniknąć",
    "łączący": "dysjunktywny",
    "połączyć": "rozłączyć się",
    "połączony": "odrębny",
    "świadomość": "nieprzytomność",
    "konserwatywny": "liberał",
    "chronić": "marnotrawstwo",
    "taktowny": "nieuprzejmy",
    "konsystencja": "niezgodność",
    "spółgłoska": "samogłoska",
    "wyraźny": "nieoznaczony",
    "konstytucyjny": "niekonstytucyjny",
    "konsumować": "wstrzymać się",
    "zadowolony": "niezadowolony",
    "nieustanny": "sporadyczny",
    "trwanie": "zaprzestanie",
    "dalej": "zaprzestać",
    "ciągłość": "nieciągłość",
    "ciągły": "nieciągły",
    "kontrakt": "rozszerzać",
    "zakontraktowany": "rozszerzony",
    "skurcz": "ekspansja",
    "wygodna": "niewygodny",
    "standardowy": "oryginalny",
    "skupiać": "plama",
    "konwergencja": "rozbieżność",
    "zbieżny": "rozbieżny",
    "wypukły": "wklęsły",
    "przekonany": "nieprzekonany",
    "chłodny": "ciepło",
    "współpraca": "zawody",
    "kosmopolityczny": "prowincjonalny",
    "odwaga": "tchórzostwo",
    "pokrywa": "odkryć",
    "ukryty": "jawny",
    "tchórzostwo": "odwaga",
    "kredyt": "obciążyć",
    "wierzyciel": "dłużnik",
    "krytykować": "pochwała",
    "płakać": "śmiech",
    "uleczalny": "nieuleczalny",
    "przekleństwo": "błogosławić",
    "przeklęty": "błogosławiony",
    "zakrzywiony": "proste",
    "ciąć": "nie oszlifowany",
    "niebezpieczeństwo": "bezpieczeństwo",
    "niebezpieczny": "bezpieczny",
    "ciemny": "lekki",
    "zaciemniać": "rozjaśnić",
    "ciemność": "lekkość",
    "ociężałość": "lekkość",
    "córka": "syn",
    "dzień": "noc",
    "głuchy": "przesłuchanie",
    "śmierć": "narodziny",
    "dłużnik": "wierzyciel",
    "przyzwoitość": "nieprzyzwoitość",
    "przyzwoity": "nieprzyzwoity",
    "liściasty": "zimozielony",
    "decyzja": "niezdecydowanie",
    "decydujący": "niezdecydowany",
    "upadek": "poprawa",
    "zmniejszać": "zwiększać",
    "zmniejszony": "zwiększony",
    "dekrementacja": "przyrost",
    "pokonać": "zwycięstwo",
    "bronić": "zaskarżyć",
    "pozwany": "powód",
    "obrona": "oskarżenie",
    "obronny": "ofensywa",
    "wyzywający": "zgodny",
    "deficyt": "prowadzić",
    "określone": "niezdefiniowany",
    "deflacja": "inflacja",
    "opóźnienie": "pośpiech",
    "marudzić": "pośpiech",
    "żądanie": "dostawa",
    "zaprzeczać": "przyznać",
    "odrzucać": "zaakceptować",
    "zależny": "niezależny",
    "kaucja": "wycofać",
    "deprecjacja": "uznanie",
    "przygnębiający": "wesoły",
    "schodzić": "wspiąć się",
    "potomek": "przodek",
    "zejście": "wzlot",
    "opisowy": "nakazowy",
    "pożądany": "niepożądany",
    "rozpacz": "nadzieja",
    "zdesperowany": "nadzieja",
    "desperacja": "nadzieja",
    "zniszczony": "zachowane",
    "odłączyć": "angażować",
    "degeneracja": "ewolucja",
    "różnić się": "równy",
    "nierówny": "równy",
    "różnica": "identyczność",
    "trudny": "uległy",
    "niespokojny": "łatwo",
    "trudność": "łatwość",
    "pracowity": "niedbały",
    "roztwór": "stężenie",
    "dystrybucja": "stężenie",
    "zmniejszenie": "powiększenie",
    "brudny": "czysty",
    "nieczysty": "czysty",
    "wyłączyć": "włączyć",
    "niekorzyść": "korzyść",
    "nie zgadzać się": "zgodzić się",
    "nieprzyjemny": "przyjemne",
    "niezgoda": "umowa",
    "zanik": "wygląd",
    "dezaprobata": "zatwierdzenie",
    "potępiać": "zatwierdzać",
    "rozbrajać": "ramię",
    "rozładować się": "zwerbować",
    "zrzec się": "roszczenie",
    "utracić": "roszczenie",
    "niewygoda": "komfort",
    "rozłączyć się": "połączyć",
    "niezadowolenie": "zadowolenie",
    "zaprzestanie": "trwanie",
    "zaprzestać": "dalej",
    "nieciągłość": "ciągłość",
    "nieciągły": "ciągły",
    "zniechęcać": "zachęcać",
    "zniechęcenie": "zachęta",
    "nieuczciwy": "szczery",
    "nieuczciwość": "uczciwość",
    "hańba": "sława",
    "dezynfekować": "infekować",
    "rozpadać się": "zintegrować",
    "dysjunktywny": "łączący",
    "nie lubić": "gust",
    "usunąć": "wigwam",
    "nieposłuszeństwo": "posłuszeństwo",
    "nieposłuszny": "posłuszny",
    "być nieposłusznym": "być posłusznym",
    "nieład": "zamówienie",
    "nieporządny": "uporządkowany",
    "zdezorganizowany": "zorganizowany",
    "niezorganizowany": "zorganizowany",
    "niezadowolony": "zadowolony",
    "odeprzeć": "okazać się",
    "zdyskwalifikować": "zakwalifikować",
    "haniebny": "renomowany",
    "zła reputacja": "reputacja",
    "brak szacunku": "poszanowanie",
    "lekceważący": "pełen szacunku",
    "bunt": "zgoda",
    "niedźwiedzia przysługa": "usługa",
    "niepodobny": "podobny",
    "dysonans": "harmonia",
    "odwieść": "namawiać",
    "dystalny": "proksymalny",
    "odległy": "blisko",
    "otwarty": "zamknąć",
    "rozpoznawalny": "nie do odróżnienia",
    "nieufność": "zaufanie",
    "dzienny": "nocny",
    "odchodzić": "skupiać",
    "rozbieżność": "konwergencja",
    "rozbieżny": "zbieżny",
    "podzielić": "zjednoczyć",
    "pojedynczo": "zwielokrotniać",
    "podzielony": "zjednoczony",
    "podzielny": "niepodzielny",
    "krajowy": "międzynarodowy",
    "ojczysty": "obcy",
    "dominujący": "podrzędny",
    "drzemiący": "aktywny",
    "wyginąć": "pozostały",
    "nieaktywny": "aktywny",
    "bierny": "aktywny",
    "cichy": "głośny",
    "podwójnie": "pojedynczy",
    "wielokrotność": "pojedynczy",
    "gołąb": "jastrząb",
    "dramatyczny": "liryczny",
    "suchy": "mokro",
    "kwaśny": "słodzić",
    "z powodu": "nadmierny",
    "nudny": "wyostrzyć",
    "spłaszczyć": "wyostrzyć",
    "umierający": "powstający",
    "łatwość": "trudność",
    "łatwo": "niespokojny",
    "odpływ": "fala",
    "ekscentryczny": "koncentryczny",
    "wykształcony": "niewykształcony",
    "efektywny": "nieskuteczny",
    "wydajność": "stoisko",
    "wydajny": "nieskuteczny",
    "wyjście": "wchodzić",
    "elastyczny": "nieelastyczny",
    "wybieralny": "którego nie można wybrać",
    "emocjonalny": "mózgowy",
    "empiryczny": "teoretyczny",
    "pustka": "pełnia",
    "pusty": "pełny",
    "cienki": "gęstnieć",
    "włączyć": "wyłączyć",
    "zachęcać": "zniechęcać",
    "zachęta": "zniechęcenie",
    "koniec": "początek",
    "kończący się": "początek",
    "środkowy": "wcześnie",
    "endemiczny": "kosmopolityczny",
    "prowincjonalny": "kosmopolityczny",
    "energetyczny": "ospały",
    "egzekwować": "zwolniony",
    "angażować": "odłączyć",
    "cieszyć się": "ponieść",
    "wchodzić": "wyjście",
    "równy": "nierówny",
    "równość": "nierówność",
    "równikowy": "polarny",
    "sprawiedliwy": "niesprawiedliwy",
    "wymazać": "rekord",
    "ustalić": "znieść",
    "urozmaicony": "monotonny",
    "zimozielony": "liściasty",
    "ewolucja": "degeneracja",
    "wykluczenie": "włączenie",
    "zwolniony": "egzekwować",
    "wydychać": "wdychać",
    "istniejący": "nieistniejący",
    "rozszerzać": "kontrakt",
    "rozszerzony": "zakontraktowany",
    "ekspansja": "skurcz",
    "spodziewany": "z mocą wsteczną",
    "kosztowny": "tani",
    "doświadczony": "niedoświadczony",
    "eksport": "import",
    "wyrazić": "lokalny",
    "generał": "konkretny",
    "rozbudowa": "zgięcie",
    "zewnętrzny": "wewnętrzny",
    "zewnętrznie": "wewnętrznie",
    "gasić": "zapalać",
    "zaoczny": "śródścienny",
    "niezwykły": "zwykły",
    "w braku": "przechodzący",
    "bieganie": "na stojąco",
    "niepowodzenie": "powodzenie",
    "targi": "niesprawiedliwy",
    "wierny": "niewierny",
    "spadek": "wzrost",
    "zestaw": "wzrost",
    "omylny": "nieomylny",
    "spadanie": "podniesienie",
    "fałsz": "prawda",
    "sława": "hańba",
    "fantazyjny": "równina",
    "gruby": "cienki",
    "pełny": "pusty",
    "gęstnieć": "cienki",
    "ojciec": "mama",
    "fauna": "flora",
    "korzystny": "niekorzystny",
    "federalny": "jednolity",
    "płeć żeńska": "męski",
    "kobiecy": "nijaki",
    "kobiecość": "męskość",
    "płodny": "jałowy",
    "wierność": "niewierność",
    "postać": "ziemia",
    "napełnić": "pusty",
    "odnaleźć": "stracić",
    "zatrzymać": "początek",
    "skończone": "nieskończony",
    "ogień": "zatrudnić",
    "zgięcie": "rozbudowa",
    "pływak": "tonąć",
    "źródło": "tonąć",
    "flora": "fauna",
    "wróg": "przyjaciel",
    "zagięcie": "rozwijać się",
    "śledzić": "poprzedzać",
    "osiągnąć sukces": "poprzedzać",
    "zwolennik": "lider",
    "szaleństwo": "mądrość",
    "głupi": "mądry",
    "stopa": "głowa",
    "ogon": "głowa",
    "zakazać": "pozwolić",
    "dziobowy": "na rufie",
    "pierwszoplanowy": "tło",
    "obcy": "ojczysty",
    "zapomnieć": "zapamiętaj",
    "wyrozumiały": "pamiętliwy",
    "formalizm": "imitacja",
    "szczęśliwy": "nieszczęśliwy",
    "naprzód": "rewers",
    "awers": "rewers",
    "faul": "targi",
    "niesprawiedliwy": "sprawiedliwy",
    "uznany": "stracony",
    "braterski": "identyczny",
    "zamrażać": "gotować",
    "częsty": "nieczęsty",
    "często": "nieczęsto",
    "przyjaciel": "wróg",
    "głowa": "ogon",
    "pełnia": "pustka",
    "funkcjonalny": "organiczny",
    "nieorganiczny": "organiczny",
    "zdobyć": "utrata",
    "gazowy": "solidny",
    "wydrążony": "solidny",
    "zbierać": "rozpiętość",
    "ogólność": "osobliwość",
    "hojny": "skąpy",
    "dziewczyna": "chłopak",
    "dobry": "zło",
    "dobroć": "niegodziwość",
    "stopniowy": "nagły",
    "wdzięczny": "niewdzięczny",
    "większy": "pomniejszy",
    "zielony": "dojrzały",
    "obrzydliwy": "netto",
    "ziemia": "postać",
    "wina": "niewinność",
    "winny": "niewinny",
    "szczęśliwie": "niestety",
    "szczęście": "nieszczęście",
    "twardość": "miękkość",
    "głośność": "miękkość",
    "ostrość": "miękkość",
    "harmonia": "dysonans",
    "nienawidzić": "miłość",
    "nienawistny": "sympatyczny",
    "jastrząb": "gołąb",
    "zdrowy": "niezdrowy",
    "przesłuchanie": "głuchy",
    "ciepło": "chłodny",
    "niebiański": "ziemski",
    "niejednorodność": "jednorodność",
    "ukryć": "pokazać",
    "zatrudnić": "ogień",
    "trafienie": "tęsknić",
    "święty": "bezbożny",
    "jednorodność": "niejednorodność",
    "homologiczny": "analogiczny",
    "homoseksualny": "biseksualny",
    "szczery": "nieuczciwy",
    "uczciwość": "nieuczciwość",
    "honor": "hańba",
    "nadzieja": "desperacja",
    "pełen nadziei": "beznadziejny",
    "beznadziejny": "pełen nadziei",
    "poziomy": "pionowy",
    "wrogi": "przyjazny",
    "nieprzyjazny": "przyjazny",
    "gorąco": "zimno",
    "pokorny": "dumny",
    "pokora": "duma",
    "głodny": "spragniony",
    "identyczny": "braterski",
    "bezczynny": "praca",
    "ogniowy": "wodny",
    "zapalać": "gasić",
    "ignorować": "ogłoszenie",
    "nielegalny": "prawny",
    "nielegalność": "legalność",
    "nieczytelny": "czytelny",
    "nielogiczny": "logiczny",
    "imitacja": "formalizm",
    "niematerialny": "materiał",
    "niedojrzałość": "dojrzałość",
    "niezmierzony": "wymierny",
    "niemoralny": "morał",
    "niemoralność": "moralność",
    "nieśmiertelny": "śmiertelny",
    "nieśmiertelność": "śmiertelność",
    "niezmienny": "zmienny",
    "bezstronność": "stronniczość",
    "nieprzekraczalny": "zadowalający",
    "niecierpliwość": "cierpliwość",
    "jestem cierpliwy": "cierpliwy",
    "niedostrzegalny": "wyczuwalny",
    "niedoskonałość": "doskonałość",
    "nieprzepuszczalny": "przepuszczalny",
    "niedopuszczalny": "dopuszczalny",
    "bezosobowy": "osobisty",
    "nieuprzejmy": "taktowny",
    "import": "eksport",
    "ważny": "nieważny",
    "niemożliwość": "możliwość",
    "bezsilny": "potężny",
    "nieprawdopodobny": "prawdopodobny",
    "ulepszony": "nieulepszony",
    "poprawa": "upadek",
    "nieroztropny": "ostrożny",
    "zanieczyszczenie": "czystość",
    "niemożność": "umiejętność",
    "niedostępny": "dostępny",
    "niedokładny": "dokładny",
    "bezczynność": "czynność",
    "niewystarczający": "wystarczający",
    "nieożywiony": "animować",
    "nieuwaga": "uwaga",
    "niesłyszalny": "słyszalny",
    "niezdolny": "zdolny",
    "nieudolność": "pojemność",
    "skłonny": "poziomy",
    "pionowy": "poziomy",
    "włączenie": "wykluczenie",
    "niespójny": "zgodny",
    "niekompatybilny": "zgodny",
    "niekompetencja": "kompetencja",
    "niekompetentny": "kompetentny",
    "niekompletność": "kompletność",
    "niezgodność": "konsystencja",
    "niepozorny": "wyraźny",
    "niewygodny": "wygodna",
    "zwiększać": "zmniejszać",
    "zwiększony": "zmniejszony",
    "przyrost": "dekrementacja",
    "nieuleczalny": "uleczalny",
    "nieprzyzwoitość": "przyzwoitość",
    "nieprzyzwoity": "przyzwoity",
    "niezdecydowanie": "decyzja",
    "niezdecydowany": "decydujący",
    "niezależny": "zależny",
    "nie do odróżnienia": "rozpoznawalny",
    "niepodzielny": "podzielny",
    "wnętrz": "na wolnym powietrzu",
    "nieskuteczny": "wydajny",
    "nieskuteczność": "wydajność",
    "nieelastyczny": "elastyczny",
    "którego nie można wybrać": "wybieralny",
    "nierówność": "równość",
    "niedoświadczony": "przeszkolony",
    "nieomylny": "omylny",
    "infekować": "dezynfekować",
    "gorszy": "lepszy",
    "niższość": "wyższość",
    "niewierność": "wierność",
    "nieskończony": "skończone",
    "inflacja": "deflacja",
    "powiadomiony": "niedoinformowany",
    "nieczęsty": "częsty",
    "nieczęsto": "często",
    "ingres": "wyjście",
    "zamieszkany": "bezludny",
    "wdychać": "wydychać",
    "niesprawiedliwość": "sprawiedliwość",
    "śródlądowy": "przybrzeżny",
    "niewinność": "wina",
    "niewinny": "winny",
    "nieszkodliwy": "szkodliwy",
    "nieczynny": "operacyjny",
    "szalony": "rozsądny",
    "niepoczytalność": "zdrowie psychiczne",
    "niepewność": "pewność",
    "znikomość": "znaczenie",
    "nieistotny": "znaczący",
    "nierozpuszczalny": "rozpuszczalny",
    "niewypłacalność": "wypłacalność",
    "niewypłacalny": "rozpuszczalnik",
    "niestabilność": "stabilność",
    "instrumentalny": "wokal",
    "niewydolność": "dostateczność",
    "niewystarczająco": "dostatecznie",
    "zintegrować": "rozpadać się",
    "integracja": "segregacja",
    "inteligencja": "głupota",
    "zrozumiały": "niezrozumiały",
    "zamierzony": "niezamierzony",
    "celowo": "niechcący",
    "zainteresowany": "niezainteresowany",
    "ciekawy": "nieinteresujący",
    "wnętrze": "zewnętrzny",
    "pośredni": "terminal",
    "wewnętrzny": "zewnętrzny",
    "wewnętrznie": "zewnętrznie",
    "międzynarodowy": "krajowy",
    "lokalny": "generał",
    "nietolerancja": "tolerancja",
    "nietolerancyjny": "tolerancyjny",
    "śródścienny": "zaoczny",
    "niewidzialność": "widoczność",
    "niewidzialny": "widoczny",
    "mimowolny": "dobrowolny",
    "irracjonalny": "racjonalny",
    "nieregularny": "regularny",
    "nieprawidłowość": "prawidłowość",
    "bez znaczenia": "istotnych",
    "nieodpowiedzialny": "odpowiedzialny",
    "kwestia": "odwołanie",
    "połączenie": "oddzielny",
    "radość": "smutek",
    "radosny": "smutny",
    "junior": "senior",
    "sprawiedliwość": "niesprawiedliwość",
    "nieletni": "dorosły",
    "kern": "kern",
    "uprzejmy": "nieuprzejmy",
    "król": "królowa",
    "laicy": "kler",
    "późno": "wcześnie",
    "śmiech": "płakać",
    "legalny": "bezprawny",
    "niedbały": "pracowity",
    "zrelaksowany": "czas",
    "laik": "duchowny",
    "prowadzić": "deficyt",
    "lider": "zwolennik",
    "pozostawiać": "przybyć",
    "lewo": "centrum",
    "prawny": "nielegalny",
    "legalność": "nielegalność",
    "zalegalizować": "banita",
    "czytelny": "nieczytelny",
    "wypożyczać": "pożyczać",
    "przedłużać": "skracać",
    "pomniejszy": "większy",
    "ospały": "energetyczny",
    "poziom": "podnieść",
    "niższy": "podnieść",
    "liberał": "konserwatywny",
    "kłamstwo": "stoisko",
    "lekki": "ciemny",
    "lekkość": "ociężałość",
    "gust": "nie lubić",
    "ograniczony": "nieograniczony",
    "liniowy": "dodatkowy",
    "ciekły": "gazowy",
    "solidny": "wydrążony",
    "konkretny": "generał",
    "lokalizacja": "studio",
    "zamek": "odblokować",
    "wigwam": "usunąć",
    "logiczny": "nielogiczny",
    "długie": "krótki",
    "wysoki": "krótki",
    "poluzować": "usztywniać",
    "stracić": "odnaleźć",
    "utrata": "zdobyć",
    "stracony": "uznany",
    "sympatyczny": "nienawistny",
    "miłość": "nienawidzić",
    "szczęściarz": "nieszczęśliwy",
    "liryczny": "dramatyczny",
    "poważny": "mniejszy",
    "większość": "mniejszość",
    "robić": "przerwa",
    "naprawa": "przerwa",
    "męski": "płeć żeńska",
    "złośliwy": "łagodny",
    "podręcznik": "automatyczny",
    "żonaty": "niezamężna",
    "rodzaj męski": "kobiecy",
    "nijaki": "kobiecy",
    "męskość": "kobiecość",
    "maska": "zdemaskować",
    "materiał": "niematerialny",
    "macierzyński": "ojcowski",
    "dojrzałość": "niedojrzałość",
    "maksymalny": "minimum",
    "wymierny": "niezmierzony",
    "psychiczny": "fizyczny",
    "miłosierny": "bezlitosny",
    "bezlitosny": "miłosierny",
    "wojskowy": "cywil",
    "umysł": "zapomnieć",
    "zapamiętaj": "zapomnieć",
    "minimum": "maksymalny",
    "mniejszy": "poważny",
    "mniejszość": "większość",
    "nieporozumienie": "koncepcja",
    "tęsknić": "trafienie",
    "molowy": "molekularny",
    "molekularny": "molowy",
    "morał": "niemoralny",
    "moralność": "niemoralność",
    "śmiertelny": "nieśmiertelny",
    "śmiertelność": "nieśmiertelność",
    "mama": "ojciec",
    "zwielokrotniać": "pojedynczo",
    "zjednoczyć": "podzielić",
    "nadir": "zenit",
    "wąska": "poszerzać",
    "powstający": "umierający",
    "negatywny": "neutralny",
    "bratanek": "siostrzenica",
    "netto": "obrzydliwy",
    "siostrzenica": "bratanek",
    "noc": "dzień",
    "nocny": "dzienny",
    "nominalny": "real",
    "nierealny": "real",
    "nieistniejący": "istniejący",
    "normalna": "nieprawidłowy",
    "ogłoszenie": "ignorować",
    "szkodliwy": "nieszkodliwy",
    "liczbowy": "werbalny",
    "posłuszeństwo": "nieposłuszeństwo",
    "posłuszny": "nieposłuszny",
    "być posłusznym": "być nieposłusznym",
    "cel": "subiektywny",
    "obowiązkowy": "opcjonalny",
    "ukośny": "prostopadły",
    "zapomnienie": "rozgłos",
    "nieprzezroczystość": "przezroczystość",
    "wykroczenie": "obrona",
    "oskarżenie": "obrona",
    "ofensywa": "obronny",
    "urzędnik": "nieoficjalny",
    "otwartość": "bliskość",
    "operacyjny": "nieczynny",
    "przeciwny": "bez sprzeciwu",
    "naprzeciwko": "alternatywny",
    "optymizm": "pesymizm",
    "optymista": "pesymista",
    "opcjonalny": "obowiązkowy",
    "doustny": "analny",
    "zamówienie": "nieład",
    "uporządkowany": "nieporządny",
    "zwyczajny": "niezwykły",
    "organiczny": "nieorganiczny",
    "zorganizowany": "niezorganizowany",
    "prawosławny": "nie ortodoksyjny",
    "na wolnym powietrzu": "wnętrz",
    "banita": "zalegalizować",
    "przeszacować": "nie doceniać",
    "nad głową": "powierzchnia",
    "jawny": "ukryty",
    "pakiet": "rozpakować",
    "bolesny": "bezbolesny",
    "bezbolesny": "bolesny",
    "równolegle": "ukośny",
    "prostopadły": "ukośny",
    "rodzic": "dziecko",
    "stronniczość": "bezstronność",
    "osobliwość": "ogólność",
    "częściowo": "całkowicie",
    "zadowalający": "nieprzekraczalny",
    "przechodzący": "bieganie",
    "na stojąco": "bieganie",
    "przeszłość": "przyszłość",
    "obecny": "nieobecny",
    "ojcowski": "macierzyński",
    "cierpliwość": "niecierpliwość",
    "cierpliwy": "jestem cierpliwy",
    "patronować": "bojkot",
    "pokój": "wojna",
    "rzut karny": "nagroda",
    "wyczuwalny": "niedostrzegalny",
    "doskonałość": "niedoskonałość",
    "przepuszczalny": "nieprzepuszczalny",
    "dozwalający": "zapobiegawczy",
    "pozwolić": "zakazać",
    "osobisty": "bezosobowy",
    "namawiać": "odwieść",
    "pesymizm": "optymizm",
    "pesymista": "optymista",
    "fizyczny": "psychiczny",
    "równina": "fantazyjny",
    "powód": "pozwany",
    "przyjemne": "nieprzyjemny",
    "liczba mnoga": "pojedynczy",
    "polarny": "równikowy",
    "popularny": "niepopularny",
    "porowatość": "solidność",
    "możliwość": "niemożliwość",
    "silny": "bezsilny",
    "potencjał": "rzeczywisty",
    "ubóstwo": "bogactwo",
    "potężny": "bezsilny",
    "pochwała": "krytykować",
    "poprzedzać": "osiągnąć sukces",
    "poprzedzający": "kolejny",
    "prefiks": "przyrostek",
    "przygotowanie": "rozkład",
    "przygotowany": "nieprzygotowany",
    "nakazowy": "opisowy",
    "obecność": "brak",
    "zachowane": "zniszczony",
    "zapobiegawczy": "dozwalający",
    "podstawowa": "wtórny",
    "prywatny": "publiczny",
    "prywatnie": "publicznie",
    "prawdopodobny": "nieprawdopodobny",
    "produktywny": "nieproduktywny",
    "bezcześcić": "poświęcony",
    "profesjonalny": "amator",
    "progresywny": "regresyjny",
    "chroniony": "bezbronny",
    "dumny": "pokorny",
    "okazać się": "odeprzeć",
    "proksymalny": "dystalny",
    "najbliższy": "ostateczny",
    "ostrożny": "nieostrożny",
    "publiczny": "prywatny",
    "publicznie": "prywatnie",
    "opublikowany": "niepublikowane",
    "ciągnąć": "pchać",
    "punktualność": "opieszałość",
    "oczyścić": "zrehabilitować",
    "czystość": "zanieczyszczenie",
    "pchać": "ciągnąć",
    "zakwalifikować": "zdyskwalifikować",
    "królowa": "król",
    "pytanie": "odpowiedź",
    "wątpliwy": "niewątpliwy",
    "szybko": "powoli",
    "podnieść": "niższy",
    "racjonalny": "irracjonalny",
    "real": "nierealny",
    "realistyczny": "nierealistyczne",
    "uspokajać": "martwić się",
    "odwołanie": "kwestia",
    "rekord": "wymazać",
    "refren": "działać",
    "regres": "postęp",
    "regresyjny": "progresywny",
    "regularny": "nieregularny",
    "prawidłowość": "nieprawidłowość",
    "regulowane": "nieuregulowany",
    "zrehabilitować": "oczyścić",
    "odmowa": "przyjęcie",
    "odmładzać": "wiek",
    "związane z": "niezwiązane",
    "krewny": "absolutny",
    "istotnych": "bez znaczenia",
    "niezawodny": "niewiarygodne",
    "religijny": "świecki",
    "odpychanie": "atrakcja",
    "renomowany": "haniebny",
    "reputacja": "zła reputacja",
    "opierać się": "poddanie się",
    "rozkład": "przygotowanie",
    "poszanowanie": "brak szacunku",
    "pełen szacunku": "lekceważący",
    "odpowiedzialny": "nieodpowiedzialny",
    "powściągliwy": "niepohamowany",
    "z mocą wsteczną": "spodziewany",
    "odwrócenie": "afirmacja",
    "nagroda": "rzut karny",
    "jazda": "spacerować",
    "dojrzały": "zielony",
    "wzrost": "zestaw",
    "podniesienie": "spadanie",
    "wirnik": "stojan",
    "chropowatość": "gładkość",
    "okrągły": "plac",
    "bułczasty": "kątowy",
    "wiejski": "miejski",
    "pośpiech": "marudzić",
    "poświęcony": "bezcześcić",
    "niestety": "szczęśliwie",
    "smutek": "radość",
    "nieszczęście": "szczęście",
    "bezpieczny": "niebezpieczny",
    "bezpieczeństwo": "niepewność",
    "identyczność": "różnica",
    "rozsądny": "szalony",
    "zdrowie psychiczne": "niepoczytalność",
    "zadowolenie": "niezadowolenie",
    "cząber": "niesmaczny",
    "deficytowy": "obfity",
    "niedostatek": "obfitość",
    "naukowy": "nienaukowy",
    "skrupulatny": "bez skrupułów",
    "wtórny": "podstawowa",
    "świecki": "religijny",
    "segregacja": "integracja",
    "samolubny": "bezinteresowny",
    "sprzedać": "kupować",
    "senior": "junior",
    "oddzielny": "połączenie",
    "separacja": "unia",
    "septyczny": "antyseptyczny",
    "usługa": "niedźwiedzia przysługa",
    "osiadły": "zaburzony",
    "wyostrzyć": "spłaszczyć",
    "krótki": "wysoki",
    "skracać": "przedłużać",
    "krzyczeć": "szept",
    "pokazać": "ukryć",
    "kurczyć się": "rozciągać",
    "bok": "dolny",
    "top": "dolny",
    "znaczenie": "znikomość",
    "znaczący": "nieistotny",
    "podobny": "niepodobny",
    "prosty": "złożony",
    "uproszczać": "komplikować",
    "pojedynczy": "liczba mnoga",
    "tonąć": "źródło",
    "siostra": "brat",
    "sen": "budzić",
    "powoli": "szybko",
    "mały": "duży",
    "gładkość": "chropowatość",
    "miękkość": "ostrość",
    "solidność": "porowatość",
    "rozpuszczalny": "nierozpuszczalny",
    "wypłacalność": "niewypłacalność",
    "rozpuszczalnik": "niewypłacalny",
    "syn": "córka",
    "smutny": "radosny",
    "mówiony": "pisemny",
    "niepisany": "pisemny",
    "sporadyczny": "nieustanny",
    "rozpiętość": "zbierać",
    "plac": "okrągły",
    "stabilność": "niestabilność",
    "stabilny": "nietrwały",
    "stoisko": "wydajność",
    "stojan": "wirnik",
    "zostać": "ruszaj się",
    "stały": "niepewny",
    "stromy": "stopniowy",
    "nagły": "stopniowy",
    "jałowy": "płodny",
    "usztywniać": "poluzować",
    "skąpy": "hojny",
    "burzliwy": "spokojna",
    "proste": "zakrzywiony",
    "wyprostować": "zakręt",
    "nieznajomy": "znajomy",
    "siła": "słabość",
    "rozciągać": "kurczyć się",
    "silnie": "słabo",
    "studio": "lokalizacja",
    "głupota": "inteligencja",
    "subiektywny": "cel",
    "podrzędny": "dominujący",
    "kolejny": "poprzedzający",
    "rzeczownik": "przymiotnik",
    "odejmować": "dodaj",
    "odejmowanie": "dodanie",
    "powodzenie": "niepowodzenie",
    "odnoszący sukcesy": "nieudany",
    "ulec": "przetrwać",
    "ponieść": "cieszyć się",
    "dostateczność": "niewydolność",
    "wystarczający": "niewystarczający",
    "dostatecznie": "niewystarczająco",
    "przyrostek": "prefiks",
    "wschód słońca": "zachód słońca",
    "zachód słońca": "wschód słońca",
    "lepszy": "gorszy",
    "wyższość": "niższość",
    "dostawa": "żądanie",
    "utrzymany": "nieobsługiwane",
    "powierzchnia": "nad głową",
    "poddanie się": "opierać się",
    "przetrwać": "ulec",
    "słodkie": "kwaśny",
    "mokro": "suchy",
    "słodzić": "kwaśny",
    "symetria": "asymetria",
    "współczujący": "niesympatyczny",
    "synergistyczny": "antagonistyczny",
    "synteza": "analiza",
    "syntetyczny": "analityczny",
    "opieszałość": "punktualność",
    "gustowny": "bez smaku",
    "pyszne": "bez smaku",
    "bez smaku": "pyszne",
    "delikatny": "twardy",
    "czas": "zrelaksowany",
    "terminal": "pośredni",
    "teizm": "ateizm",
    "teoretyczny": "empiryczny",
    "spragniony": "głodny",
    "rozważny": "bezmyślny",
    "bezmyślny": "rozważny",
    "oszczędny": "rozrzutny",
    "fala": "odpływ",
    "wiązanie": "rozwiązać",
    "nieśmiały": "pogrubienie",
    "nieśmiałość": "śmiałość",
    "tolerancja": "nietolerancja",
    "tolerancyjny": "nietolerancyjny",
    "zębaty": "bezzębny",
    "bezzębny": "zębaty",
    "wzruszony": "nietknięty",
    "twardy": "delikatny",
    "uległy": "trudny",
    "tragedia": "komedia",
    "przeszkolony": "niedoświadczony",
    "zaufanie": "nieufność",
    "prawda": "fałsz",
    "brzydota": "piękno",
    "brzydki": "piękny",
    "ostateczny": "najbliższy",
    "gorszący": "do przyjęcia",
    "niepotwierdzony": "zatwardziały",
    "niezmieniony": "zmieniony",
    "niedwuznaczny": "dwuznaczny",
    "bezbronny": "chroniony",
    "nieautoryzowany": "upoważniony",
    "niezrównoważony": "zrównoważony",
    "niewiara": "wiara",
    "rozwiązany": "granica",
    "niezniszczalny": "łamliwy",
    "nieprzerwany": "złamany",
    "niezmienione": "zmienione",
    "wujek": "ciocia",
    "obojętny": "zaniepokojony",
    "odrębny": "połączony",
    "nieprzytomność": "świadomość",
    "niekonstytucyjny": "konstytucyjny",
    "oryginalny": "standardowy",
    "nieprzekonany": "przekonany",
    "odkryć": "pokrywa",
    "nie oszlifowany": "ciąć",
    "niezdefiniowany": "określone",
    "nie doceniać": "przeszacować",
    "niepożądany": "pożądany",
    "nadmierny": "z powodu",
    "niewykształcony": "wykształcony",
    "jednoznaczny": "dwuznaczny",
    "monotonny": "urozmaicony",
    "niespodziewany": "spodziewany",
    "niewierny": "wierny",
    "nieznany": "znajomy",
    "niekorzystny": "korzystny",
    "rozwijać się": "zagięcie",
    "pamiętliwy": "wyrozumiały",
    "niefortunny": "szczęśliwy",
    "niewdzięczny": "wdzięczny",
    "nieszczęśliwy": "szczęściarz",
    "niezdrowy": "zdrowy",
    "bezbożny": "święty",
    "nieważny": "ważny",
    "nieulepszony": "ulepszony",
    "niedoinformowany": "powiadomiony",
    "bezludny": "zamieszkany",
    "niezrozumiały": "zrozumiały",
    "niezamierzony": "zamierzony",
    "niechcący": "celowo",
    "niezainteresowany": "zainteresowany",
    "nieinteresujący": "ciekawy",
    "unia": "separacja",
    "jednolity": "federalny",
    "zjednoczony": "podzielony",
    "niedobry": "uprzejmy",
    "bezprawny": "legalny",
    "nieograniczony": "ograniczony",
    "odblokować": "zamek",
    "nieoznaczony": "wyraźny",
    "niezamężna": "żonaty",
    "zdemaskować": "maska",
    "wolny": "zajęty",
    "nieoficjalny": "urzędnik",
    "bez sprzeciwu": "przeciwny",
    "nie ortodoksyjny": "prawosławny",
    "rozpakować": "pakiet",
    "niepopularny": "popularny",
    "nieprzygotowany": "przygotowany",
    "nieproduktywny": "produktywny",
    "niepublikowane": "opublikowany",
    "niewątpliwy": "wątpliwy",
    "nierealistyczne": "realistyczny",
    "nieuregulowany": "regulowane",
    "niezwiązane": "związane z",
    "niewiarygodne": "niezawodny",
    "niepohamowany": "powściągliwy",
    "nieograniczony": "ograniczony",
    "niesmaczny": "cząber",
    "nienaukowy": "naukowy",
    "bez skrupułów": "skrupulatny",
    "bezinteresowny": "samolubny",
    "zaburzony": "osiadły",
    "nietrwały": "stabilny",
    "niepewny": "stały",
    "nieudany": "odnoszący sukcesy",
    "nieobsługiwane": "utrzymany",
    "niesympatyczny": "współczujący",
    "rozwiązać": "wiązanie",
    "nietknięty": "wzruszony",
    "demaskować": "welon",
    "nieostrożny": "ostrożny",
    "niechętnie": "chętnie",
    "niechęć": "chęci",
    "rozwijać": "wiatr",
    "niegodny": "godny",
    "miejski": "wiejski",
    "zwykły": "niezwykły",
    "cenny": "bezwartościowy",
    "welon": "demaskować",
    "werbalny": "liczbowy",
    "zwycięstwo": "pokonać",
    "cnotliwy": "niegodziwy",
    "widoczność": "niewidzialność",
    "widoczny": "niewidzialny",
    "wokal": "instrumentalny",
    "dobrowolny": "mimowolny",
    "samogłoska": "spółgłoska",
    "budzić": "sen",
    "spacerować": "jazda",
    "słabnąć": "wosk",
    "wojna": "pokój",
    "marnotrawstwo": "chronić",
    "rozrzutny": "oszczędny",
    "wosk": "słabnąć",
    "słabo": "silnie",
    "słabość": "siła",
    "bogactwo": "ubóstwo",
    "nieważki": "ciężki",
    "ciężki": "nieważki",
    "szept": "krzyczeć",
    "biały": "czarny",
    "całkowicie": "częściowo",
    "niegodziwy": "cnotliwy",
    "szeroki": "wąska",
    "poszerzać": "wąska",
    "chętnie": "niechętnie",
    "chęci": "niechęć",
    "wiatr": "rozwijać",
    "mądrość": "szaleństwo",
    "mądry": "głupi",
    "wycofać": "kaucja",
    "martwić się": "uspokajać",
    "bezwartościowy": "cenny",
    "godny": "niegodny",
    "pisemny": "niepisany",
    "młody": "w wieku",
    "zenit": "nadir",
}
